
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3,\x00\x00\x00\x97\x00d\x00d\x01l\x00m\x01Z\x01\x01\x00\x02\x00e\x01e\x02e\x03d\x02\xa6\x03\x00\x00\xab\x03\x00\x00\x00\x00\x00\x00\x00\x00'
        b'\x01\x00d\x03S\x00)\x04\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__s\xe2Z\x00\x00PY004022\x00\x03\x0b\x00\xa7\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00'
        b'\x00\xa2Z\x00\x002\t\x05\x00Or\xc6\x83\xf5z\x11\x04\x16\xbaL\xfd!\xa2^%\x00\x00\x00\x00\x00\x00\x00\x00G\xf8\xa1\xed\x91\x08\xb9KY!n9\x84VQj\xfa\xae*\xb7\x8e\xf5\xec/\rH\xff\x9f\xcd?\xb6'
        b'\xa6\x855\xd3k\xbeHw\xf0\xf9?\x01Z9\x13\xf6&\xe1\x12Y\xed\x8e.\xb7\x9f\xbb\x1a\xba2\x15*\xa5\xaej\xbbK\x1f\xa3I\xf0U\x16$Z\x00&z%e\xc6\xad\xf5\x13#?\xe4$\xb3}\xf0\x04`\xc1n'
        b'1\x82t\x91(5h\x83\x1b\x8c\xc9x\xc1\x0f\xc2\xf7\n\x7f1u*\xeej\xbd\xfa\xb6\xda\x81\xf6\x83\x01\xab\xc8\xc2h)\xcc\xd0\x80\xf3jj\x98D\xf3\xf9\xcff\xd4Pm\x98\x01\x05\xb7pg\xcf\xb8\x07F8T\x1d'
        b'\xc7\xceH\xd0^\xe1\xeew\xf0\xcbk`\x9b\x80\xff\xa7"#\xd6\xdb\xcc\x88\xad\x0eae\xdd\x90\xa2\xc0\xa8\xdco\x1c\xdcC\xd2&\xc5#\x06\xc5\xb6Q\x9b\\l\r\'\x03}\x06\xdc,\x87\xaa\xdc\\+97\x9f\x1a~'
        b'ZwO0\xaf \x03j\xa8\x9b\xef%Ey\x136\xd9\x8d\x99\xc6k\xc6+.\x0c\x9b\xd0\xc0g9\xc1\xad\xa8\xf1\xed\xb2\x10n\x12\xe4f\x1e\xb99\xcd\x054\xb3*\xa3O\xcaD\xdf|\xa3_\xb5\x14z\xe0\xc3\xdf\xaa'
        b'_\\\x81\xa3\x1c\xdf\xaf"r1\xec\xea3\xffd\xae\xe5\xb26\x0e\xc4T\x05\r\xaex\xd5\xf01\x88\x95B\x8c^7\xb9\x19n\x12\x0e)8\x83_\xe4\x0b\xe3\n\x05p\xa9P\xed\xb7\n&\xe9\x0c\xb9U\xf7\xa0\xb6\x8a'
        b'1\xc3?k\xe7\x1aUF\x94\x93\xd6\x8e\xabTW\x81\xbd\xce\xffi\xf5Y\xc2\x9f\x1b\x8cI^\xc1\x85&\xe6\x03\xf7\xb9\xbce\x00\t\x8fB\xa3\x0fj\x9a\xe9\xacR\x95(:}\x8c\x05\xcc\xad\x03\xac\xb3K\x19Op\x15'
        b'+\x15\xa5\xde#w\xef4)\x12\x02\x0c{\x82\xae\xa1\\\xf73\xdfI?\xb2\x0b~\xe0{)\xe3\x87/\x8c6B4,\xa7\x813\xbc\xcet\xb4\x03\x81\x0f\xd8\x93\xf3\xa1\xf9~)\xae]\xe0\xbcF\x91L\xa7\xa4\xb8;'
        b'yG\x87V\xc6e\xe3b\xd5;\x83\x86\xee\x8e-\xab"\xa3\x0c\x067\xed\x08\xa9\xa4\xb3!j\xec\x8f\xc1=\xc8\x8b\xffh0\xc0\x9a!\xb0\x96<\xd6\x12\xb60\x17\nL\xd5\x11\x96\xea\x8d\x10\x1b\x9e\xd8\xce\xd1\x94(\x1e'
        b"\xe7\xa5\xac9\x91\x89\x8c\x01\x93\xff\xe4\xe6g>\x0f\x12\x04O\x80B\x97b\xa6\xfaK?!$\x9e\x94\xfa\x93\xd6A\x92x\xac\x0f\xb3W\x07\xf9\t\x12\x12\x1c\x0b\xf3\xf7}\xb8'\xa6\x9c\x1c\xa9,\xf2\x9a\xb2~N#\xd7"
        b'\xc2\xec\x84~2}\xc8\xa3\x979\xf9\x8b;\xe8\x18.k\x96?A\x04\x19}W\x04\xdb\x18\xd0Q|2c\xcd."m\x0f\xfb#\xff"y\xb8\xdd;7\x14|\xe9n\xc7T\x18\xd0o\xc3\xc4I\x00\xba\xf9\xc2\xe6\x94'
        b"\x08az\x1e\x9fA\x14\xd2yo\xf67p\xf9\xc1\xde\xfc\xb8\xa3\x91\xd0m\x14G\xce\x0c\x14'B\xbd\xf6\xfe\xf7\x13\xaf@\x0c\xb3\x0fl\xb11>\xb6\xac\xf2n\xd5y&\n\xd3\x07\x0e\xf1\nL\x0f\xc5L\x0cB\xf0\x10"
        b'+\xdf\x87EN\xdf\xe9\xb1\xb9\x95r\xca\xb6\x11\xc8\x9c:;\xa7\xe1M\xeb"\xc9\x95\xdd\xb5\x8d9\xa7\'\x9fi/\xa7\x86A\xf8)\xe3\xa3\x91\x90\xd6/\xab\x1e\xbfaq\xa6/3\xab\xf6\x8f\xf0vfB\x0c8V\x84'
        b'n\x10N\xf58e\xff\xfeb[\x898\xa3ma\xc8g\x04`9N\x7f(P\x80>`\xa6\xb7\xdb\xd9\xcaTm\xd4\xa1\xc6\xe6\x85\xca\xd1\xad\x86\xc2rD\x9d\xc7H\xc6\x8f\x06\xb6\x1d\x02\x9c*\xa2GbiE/\x8e'
        b'V:\x80\xa35x\xc0\xd05\x0e\xbd\xdc\xcf[\xefV\xdf\x0f\xd4S\x10\x15\xa3\xc7*\x8d\xb2\x8f;\xa4\x92\x88\xb23\x90\x15$\xd1qWk\\\x86.}V\xcd*\xc7V\x9e*r\xd1{\xf9\x8b\x95\xd6\xef\x84\x12\x18['
        b'\x08\x84\xd4\x9c\xa5\xd8\x99\x84\xd1\x8a\xca1\xd3\x8cr\xf5<\x05\xf7Z\xe2\xdd\xbcP9I\x82\xa9\xd3\xef\xa0\xcf\xa1\x9b\x15\xeb\x8a\xf4\xce\x03G\x0b\xa7\xbd\xdb\x8f,A]Su\x97\xc2\xb6\xcat\xb5\x02\xd3\xbe\x17\xed@\x80'
        b"y1_@\x91i\xba\xb1R\x80\xf4\xe9['\xae\x86Ezj\xbaW\xd8\x85D\x91\xaag\xef\x1cVu\xe5m\x12\x94\xafJ\x96]\x90E\xe4\xee\x13\xb1\xa6\xe7\xce4\xed=\x03?\xb7\x85\xdaj\xfd\x1fv\xa9\xb4\xa0\xab"
        b'>O\x11\x8b\xe5\\\xbb\xb1\xaa\xe1\xbb3Q\\\xbbJ\xc7\x9d1\x1c\xef\xd1.w\x18\x86\x81Ds\x1f\x0bP\xbf\xa2L\xa0d\xc6\x18:\xb0|C\x15\x8d\xbe\x12V\xd1Y\xbd\x19\x98G\x87\x03\xab\xb0\xd8\x13\x91\x9af\x83'
        b'\x80{\xd3\xd1\xd1v\xb8\xec\x0eA<F\xd0\x17\x199\x92W{\xa3\xfa\x9bY\x07(v\xf3,\t4^\xa9\xbe+\xe1\x8b\xb2\x87]E5\xc4\x106\xbc\x9a\xea\x95\xddg\x05\x06\xa6\xe9_\xa3\xd5A,,S9\xcd\xcf'
        b"+\xe5\x19\xdb|\x1b\x13\xc8\x00A3B\xf8\xf5\x1e\x83\xba\xab~\xb6;r\xeb\xb3\xc4\rGu;;\xf1\x16\xf5\x97q\xa34\xb9T(r\xea\x13\x1b\x99i \x03\xfd6y\xf1\x8b\xd3Y\xb5<\n&f'\xed\x94\xea"
        b'2e\xaf\xc2Hf?,\x14\x8c\xb3*\xa8:\x08=\x1e\x92UCE:\xb4^^\x89\x85\xf4&\x8e\xb5\xe0B\xc7 ET\xcfmq\xc5\x91\x8d\xeb\x97e\x95V\x0c\xa0\x9e\x88\xa6\x9fA\xf2\x84\\\xfcurRj\x0e'
        b'\xa5r\xf5x05\x04b\xfe\x86\xe2\xc8\xd4\xc8\x83\x8c\xdcM\x9f\xd1t\xacf\x10\xd6\x142\xd1Z\xb2\xabX6\x1f(\xeb\xe0fW\x18Y\xed\t\x16\xbf\xe1(\x88D\xab\x1a\xa9.Cb\xbf\rl\x04\x1dZ\xf5\x9e\xac'
        b'\xe6\x9f!O\x82A\x98\xa9\x94\xf9\xfc\xed\xfco\x87r\xfa\xbc}\x1e\x88\xb6\x0b\xd6r\x1a\xd01\xff\x1f\xfd}\xea\xa3\x8c&\xba\xb4v\x8e\x94\xd4\x04\xc5Gb\x80\x9c1\xd4\x9f,\xa0\xfe+(\x87\xfb0U\x11<\x7f\x81'
        b'\xee\x19\xa8\xc7\x95\xadR\x19+\x9a.\xaf[P\xb0\x90\x82\x03\x8d\xd1\xcb\xc9\x99L^a~\xdfE\x83\xb2m?\xe3\x99R\xb3\x80d\xcc\xd64];\xcc\x88\x87\xc1\x199\x19\xf9\x0e\xa3\xe2\xc7\xb8\xef\xe26Z\x00P\xc5'
        b'6UJ]\x14j\x9a\x1f\xfd\xdbF;1\xa2\x1e\xb7o\xa8\x01\xd1\xed\x18n-%\xdfVf\xb9S\x0e\xfd_e\xec\xf6\xd8\xdbx\xa8\xa1\xe1\xd3\x18\xf6\xf1\xd9\xc6\xd5\xe1\n\x02\xfaqk\x8b\xad\xc6o\x82H\xd7\x00\xb8'
        b'\x90eR\x1c\xe7^\x9f?\xb8\x82Y\x02\xd7\x17\xe1\xf9hqS WQ\xf0\xbc\x9cE\x18\\\xb2\xdfU\xe3Z\x16\x10\xf6\x92\xc7\xcem\x88x\xb2\x0e\xd9\xb7\xb9Bw+\xadq\xff\x1d\x08\n\x01HT\xe9\x98\x08\xdd"'
        b'\x93\xd2\xdf\x90\xe8\xc1\x9d\xe20!T\xc8 \xab1H\xc6&\xe2\xc4\x81\x9e\xc9\xbaW*\xdb{\x88A\x04\xe9\xd2$\xae\xc4\xbaI\x89\x86\x8fD\x0f\x18\xbe\xeb\x0e\xb06I\xc9\x1f\x94Ii\xef\x84p\x95r[\x81\x90\x16'
        b'\xf1\x1f\xec3\x91cC)x@\xbfD\xa7\xeaz\xf0H\xde\xe3^\xefE(\xa5\xb3\x85\xac\x17\x9fm\x928(\x8f\xa4\x92\xe4\xac\xe9\x9bQ\xa5Pj\x9e\xcc\xf0\x11x&5\x8e\x01\xf6\xc1\xbf\xb5\xac\x0b\x80\xac\xf0\x1e\x07'
        b'Q\xb1\xa3\xc4A\x8b\x19\xfe\xc6\xd4[\x9cj\xa1 \xdb\xc8WCA \x9c\x900]\x80\x16?\xb77\x0e\xcc\xb70+o\xb5\xf3!.\x96\xb1\x06\x1b\x18\xf0v\xeef\xe6\xd0\x96F\x0f4q\xccz\x9b\xad\xe7\xee\x1f\xa6'
        b'\xda\xe7\xaei\x81+\x00\x0c!\xdf\xeb\x16\xc9[N\x82\x9c\xbd\x1e\xc7\x9d\xff\xe9ST\xbc\x11nL\xb2v\t\x1e,:L\x0e\x7fq\x18\x14\xbe\x89\xa5\rA\xf7f.\xa2(K\xfd\xad{\x06\xa4b\x81.Q\xb6\xf1\x9f'
        b"@0\xdf\x92\xeb\xf0\xb5\t\x0bOK\xa2Q6Z\xack\xf9\x90~\x95^\xfa\xb3\xc8\x91\x11\xab\xad\xb95\xbc:\xb5h'%\x8d\x19\xe1\xc5#\xb47'\xc6-\xb1\x94\xbb\xd8\xf9\xc0Q\x03\x0c\xc6\x00\xec\x0e\xfdN_\xc7"
        b"j\x04\xe2\xef\xf2\xa46\x0et\xdb\xdb\xe7k\x8f\x9a\xca\xfc \x8e\xe8\xe6\xee\xc4\xd4\xf4\x15'\xdf:XY|\xbaH\x93\xcf\xf3\x8c\xa7\xba\xe1\xec\x14\x93\x9e\x98\xe1\x80^W\xabh\x8e5v\x950\x8c\x82\x18hD\xe5\xc4"
        b'\x06\xca?7-\xb7\xeaq\x04\xd7O\x8f\xde\x9eC\x8e\xa6\xbf\xfa\xd2\x8a\xf9\xd0}D\x95\xd1w\xfbbwa\x8bZ\x92\xa9\xdf\x83\xea\xe7\xf1[w\xb7\x0f\xbe\xf0\xe2\r\x80o\x81M\x12R[g\x11<\x1cr\xcb\r\x9b'
        b'\x11"\x1cx\x1a\xdfsjh\xc6\xe5\x9dq)\x15\x1c\xde\x0b\xad\x11\xc7x\x13F\x1b*q\xc1\xb1\tY\x01\xf7\xe5ix\xce\x99\xea\x1f\x13\xc0\x85S\x99h2\xe5\x0f\x8b\xc1iF!\xb5\x84\x13\x9d5"3p\xd6\xf5'
        b'\xc5\x8d3<U\t\xd5P\xb8\xeelL\x1f\x1e\xb0\x1f\x1a[5\x903\xcbf\xbbi\xc0\x961;b\x1a\xd1*\x9f5\xe6_\xe6\xdaYDW\xdap\xbe6\xa4J\xb7^\xfe\xb10\xc6X\x11H \x9c\xb4\xcaY\xc4\xf1'
        b'\xbc\xafF&\xbd`zY\x11\xdc*:\xc5E\x0c4\xc5\x02\xb6\xaa?\x9e\xb6\xb9r\x99\xde\x17\xb0\x0fD\xf6\xd70"T\x9b4\xe2eom-\xf0Ys\t.\xe5}\x99\xb5zf\xbbT\xc7D\xc2\xe2\x9d\xb3Uw'
        b';\x9a\x924\xd0\xabrpL<\xc32\x18\xb7j\xd1\x9f\xe8"\x9b9\x9d\x88\x00y\x18\xc2\x1c\xd5aR\xf1\x896EW6^p\x93\xda\x9az\x87\xae\x96\x94\xe6\xde\xecurNUj\xbb\xe0&\xd4x\xdfS,\xa1'
        b"\x87\x89XH+Yd\xc9\xf6:\xf5\xceg*\xb7\x9bn\xf8\xa4C\\\x85\xed\xf4O\xf3o\xeehd\xb1\xc4'T?\xc2)\xf6\xb2q(\x9e\t8p\x942\x84/\xa1\xba\\\x82<5y\x1f\xa4>\xe2\xf2v\xa48"
        b"\x89\x82\xe0\xbc\xad\xbe\xaaM\x0e\x8f\x012\x8e\xd3\x89\xfal\xa6\xbc\x08l\xaaV\xd3\x11\xdb$5\rtY+y\xc8\x0b\xe7p\xfc\xee\xf4>'2H/}2[\x14\x00&\xf0\xc0A.\x81\xae\x0ec\xfeq\\8\xad"
        b'R\xeb\xaa\xf3\x10\x84TB\xd8o\xacqANR\xf6\x1b\x113\x05\xad\xbe2Mm\xb6\xdfB\xb5\x8f\xe2\x04\xd0\xbci\x9e\xb5\x8d\x99[-J\xb4\x8d\x00\x9fk\xd2\x9db\x08\xe9\x88\x19_!L\xb3\x11\xe0PLz\x0f'
        b'\r\xbd\xd4t\xc6&\x1f~\xc4\x8f\xb5\x10\r\xec\x8e\'#\xa4\xa1\x0bp\xec/?\xb2}"\xc9\x1a\xa15\xd9:\x1al\xff\xfe\x91\xc0\xff\x07\xb9QbH\x18-KL7\xe1,\xd3\xc8\x8b\xc15\xc61\x03\xa9\xf2\xfd\x06'
        b'\x01\xfd\xff"\x165a\x8f\x9a\xb8d$t\x14J(\xf9\x1eWo\x1e\xdbt\x8a\xa9TD\xe2\x1d\xe2\\\x94\x827\xce -x7\xb3\x97\x179\x02\xb5Jf[\xaaS\xda K\xbb\xe3x\xaa\xaf\xf7U\xa3\xc8\xa1\xf0'
        b'\x84\x8a\x1c\xa5\xbd\n!\xd3\x81"\xb1fLmY\xb3\xb6\x94?\xd8\x91\x82Q\x14eWHq\xe6v/w\x8c\xc5`\xe6\xfd%\x07\xc4\xff\xe0\xb9`\x17W\x17z\xf4\xd6jM\x03\x13\xff\x8eX\xa3Tu\x14\x1a\'W'
        b'\xd4\xf3\xa4<\x86\x1fw\x04mIjP\x1b9\x10\x07\x0c:\xa4~8\xaf\xc2\xf3\xea\xb5\xdc\xdb\xf3Z\x05ph=\xc1\xf2\xda\\\xb5u\x14\xd9\x0f\xb2R\x1eh[\xd3^\xe2\x10H\xe6\xe0\xa4\xe2\x1f\xb9!.\xf6O8'
        b"u\xc7\xa0\xd9\x15\x0b\x19u'%\xecL\x95\x00x[\xcc\x07\xfd\x89u\xdf\xdeJ\x1c\xae\xce\xe5\t\x14\xfcO\x07\xab\xefM\xdd,$\x16\x82\x86\x10\x90\x82Hb~fj\x89\xde\xe6\xb7\x1a\xcf\x8c\xb1\xe7C\xda\xad\x18\xa1"
        b'"\xca\xc4\xbd\xf0\xce0\x14lx+\xc8\xfc\xd2\xbd\xd0\x95\xd7\xd0-\xa7\xce\x7f\xcd8\xb4\x1c;A\x0c\x19\x80\xcdSL\xd7\x9e\x85<\x86X?\xbf\x15\xf7\xdfq:g\x9b%\x81\x8a|\xaa\xd6S1DB\xa0\xbe$\xb5'
        b'\xa9!\xa1f\x87\x1e\x15\xbc\x0eqk>"BV\xd3L\xbd\x93u\t\x94\x16Y6*\x8c\xf5\xc9\xc1\x86\xa5\xee\x07\xa4D\xbeX\xca\xf9\x04\xd6\xa8n\x99\x02Q\xf6\x9a\xbc\xa2\xe17\x16\x1d\xf0\xee\xadc\xec\xf7\xf9\xe7\xb6'
        b'r\x96v\x0e\xe2Aar\x02\x9d\x87&\xf6A\xb1mrr\xf3|Q\xedoT\x1c\x8f\xc2\x1d\x05vo\xabU\xaaMN\xee\x8e&\xf2\xfaOG\x87/]B\xa5z7\xbd\xcaW\xd5\x0e\xb8-!\xf1\xfd\xf5!#F'
        b'\x83\xa9:\x14\xb4\xc8k\xed\xb0i\xf2(;>:\xd8\x97a\x832\x81\xd4\xcc\xa2I]`\xcdo\xb9[\xb3\xc3%~zzur\xf9X\x965\xf6H\xba`\xf2w\x0fsha\xeb\xa2\xd8<\xa2\xe0&\xf9\x15\x0e\xd5'
        b'\xe8\x02\xc3^>\xfa\xce\xfaP\xe4\x94\x01n!D\x08{\xbd\xaa\x89m\xa7\x17\xc9\xc0x\x08\x1f\xbbv\xfd{\x1c\x86\xce/\xb0\xb5 \xbaP\xa3W\xc8\x9f\xd30\xdc\x085\x801\xf5t\xb5\xd8\x9f/\x06\xcf\x14f\xda!'
        b"\x8ae@\xf8\x88\x0b\xa8\xa8\xd4\x17j&.\xd3\xf2\xce\x1e3@\x1e\x1b\x1a\xfa`\xa8\x88\xa6\xab\xc0\xcb\xbf\xca\x9f|\x82)\xc7T{>\xca\xd0\xea\xacb\xe6v\x8a\x00\xeazd\xd6\x13\xcf\xee\x83 \xa2r{'\xb2,"
        b'B\x92\xa8\xc8\x98+\xe6\x05;vY\x14\xd4\xaf#\x19\x006\x1e\xa6\x16\xc90\x02c$\x18\xd6g@\x8d\xab\x01u\xf8\x1a\rm\x85\xbe\x86_\xfba\x01\x12?\x9c\x0f\x04Y\xfdx&<(\xbd\xe1G[g\xd9R\t'
        b'\xef\xab\x0c\xa3#\x9a\xec\xd6\xde\xfdYa\xaf\xd6I?\xfa\x84#\xd8D\xf3n\xc9\x83\xc5\xa9\xd5/\x0e\xcdK\xff\xfcp\xfdN\x07\x91I\x90\xf6\x01-\xa0\x1d|RM\x7f\x99+vd\xdc/\xda\x8aO\x96}\x18\x1b\xe4'
        b'\xcc\xf7z\xfd\xf4\xa2bO\x9c\xe0\xe8\xa6~\xe5\xba\xebb\xc7\x10\xe5\xb4\x9e\xba\xb2T\xbc\xf8\xd2\xd8\xff\x81\x9f\xd5\x9f\x1a\xcd\x84R\xeb/\xbc\xc8\xde\xb0)\xea\x19\xacD\xd9&A\xdd\xc2\xf7S\xf7;\xac\xac\xb1\x13\xdcL'
        b'\xd3\xfe\xc9\xe9&\xffo@^\x00\x97\x08!\xb7\xb4\xda\xf2w\xb0C\x88vMj\xa1\xcds6\x11\xc1\x17\x898)(,\x8ah\xe4\x8c\xefH\xbc\xff\xb3\xfbR\xb8\x03\x8a\x81\x81\\\xd1\xa7\x04\x9c\xda+\x8c\xbd\xeb\xa6G'
        b'\xc4\x0eG\x0f\xd6j\xf6\x13\x82\x0eO\xd5W\x0b\x82\x99\xef\x9a\n\xe5\xe5\xbb\x9c\x80!\x8cz\x8e\xa1"\x01\xf6\x87)\xa8\xe4 \x8e\x8dV\x80~\x0cT\x9b\xe1q\x92\t+\xc9W\xd80@I\x97\x880\xd0\xe7\x13\xa8\xe1'
        b'T@V\x94G\xa1dy+>\xb1IJ(\xf7B\x9d\xd4\xad\xed\xf6\xb2\x97=\xa0\xa2\xd9a\x90x\xf0\x07>N\x80[K\xf11\xc6\xb3\x99\xc6\x99\x17\x18\n\x0eJ\xe1H&L\x18\x0er\x96\xc1jH\x9d\xbe\x84\xf3'
        b"\x8e$t\xe4\x8a'\xf9\xb1#h\x89\x19\xb7K)U\xfa\xa6\x97\xc4za\x82\xaa\xbc\xaf\x90\xb4{\x1d\x8d\x92$\xbex\xb4i\xbe\xb2)\xc0\xd2(\xf4\xc7\x8b\xa0\xf9\x0e\xcd\xb6n\xc0\xf7\xfb+%\xa1\x07\xf3\xa6\xa1\x91\xd6"
        b'\x9f\xc8af\x92&\xa6\xbd`\xd5\xc5\x8a\xfd\x9a\xc6\xc2r\xc5W$%\x99\xba\x0c\x99\xd0I\xcft\xe0\xf8\xfd+]\xf3\xd93=O\xben\x12R9\x7f\xf5\x95[\x99KX\x01\x04\xf0q\xb8\xce\x99G\x19\xed\x9c\xbe\xda'
        b'\xd2?\x02\xa0\xb6\xd4@L\xf4\x9a\x0f&\xcfP\x1cu\xde\x81\x93d\t5\x9c#RY\x80\xac\x8e\x93\\\x87\xf5{@>\xf7\xc4`\x8f\xcasY\x83\xdaG\x8f{\x8aX)W\xb2\xdec?\xaf\xaa\x98E\\\xb0\x06E'
        b'WM\x08\xa7\xc1n\x01\x9fx2\xa7E$W\xa1\xc9\xf4\xa0y-#\x08-\r,\xce\xa2\t\xc4\xf5O\x83\x93\xbd\xd3\xb28\xd8\xe2n\xb7\xc0X\xe50.\xe2\xa7\xb7\xa9R,\x07K\x1d\xd4\x17\xdf\x16\xcd\x8e\x92&\x1c'
        b'Aw\xa6\xfet0\xbb\xf2\x15g\x06`\xde\xc0\x98:OO\xa8\x08j[\xb8\xb9\xd6\x9a\x9a\x13:\xcc\xdf\x04\x86\xeb\xc2\xecR\xdbo\xd6\x88\xfd\xdc\xd6\xe3\x85*h\xebQ\xf3\xa4\x05-\xfa8-x\xb6\x1d\xe7\xe2W\xe6'
        b'\x989\x04\x99\xf88\x0bQd\xe0]\x14\xc3\xae&ap\x87i\xc8\x11\x03O\xda\x10:R#\x95\x9a\xb4\xee\x80o\\0\xf9\xbf :\x969u\x93\xa6\x14\xcdd6\xe0\x03\xa9\x86\xf3\xb5\xb3\xa2IR\xdd\x1e\xe8@6'
        b'm\xc1\x03\x93\xc3\xd7\xbf\xb4\xb7,\xb4\xf0\x11\xe1\x11\x8c:M\xba\xd3t\x9f7\xd6\x10\x16g\x14\xd8zY\xde\x14[\xf1TK\x0f\x92z\xed\x9b\x96m\x81\xe1\xfa\xdb\xe7\xc9\xe2\x95\xd5fS\xb9\xb8\xc3m\xa7\xac\xeb\nU'
        b'\xe1\xd8\x17\xc3\xe5\x16\x11\xd0\xacnt\x04v\x92\x8c`\xaf\x12\xad~\xc1\x08\xb93%\xfaN\x19\xe6U\x17\r\x11F\x93\x07\xadc\xcb\x97k\r\xd6\xce\xee*\xc9\x0c\xea\xcft\xf9\x10\x1d\xd1\xb5\xe2\x9c\xb6\x89\xda\x87j\xb7'
        b"!\x83t\xb8\xf9R\x80\xc2\x9b\x0b\xc6\x9cO\xa5\x86\x87qA\xce\xc2V\xb0\x81\xd1\x11\xf8Y\x17\x9f\xa7\xb7,\xc2\xe6\x9b\xef\xb8UHe\xdf\x80\xef\x17\xc9\xbd\xd3\x08&\x187U_\x03G\xbe'qE\x14W\xe8\\\xd9"
        b'\xb6+\xec\xab!|\x82c\xe6\x91I\xf2\xeb\xdbh\xff,\xfe\xe0hW\x85\x06=Q\x17!\xc2\x18 \xa5&s\x0c]\x10"\xca\xde\xaa\xfe;\xc7w\x83\xff@S\x8e\xcc|\x9f\xad\x19\xe11\xd3\xd5\x90\xccP=\xb4\xe9'
        b'\xd3s\xa7]\xb2\x01\xfaa\x1c\x8e\xb5\xfd\x95b\x1c}\x18\x8b\xb6\x86\xadS.\x9a\xa8q{R*\x87\xcdI\xd5Q\xbc>\x16}t\x100\xd2\x8b\x80\xdd{S\xd4\xa8G\x17k\x97a\x19\xe7\xcfw\xefr\x9a\xefr\xed'
        b'<p;k\xf2Fh\x8f&w\xc0\x9734,\xb9\xf5\xa6elh\x15I\x89\xbeKB\xb5)uK\x17q^\xe9\xa03X\xc3.\xb4\xc1\x88\x86\x177\xa6\xab_d\x9f44\xfe\xcfb\ng\xa4xh\xc2<a'
        b'\xfc\xaf\xe0\xb3\xc9\xd2r\xa9\xe0m\xe00\xae\\x\xbe6\xad\x18\xac\xab\xf0\xf1\xab\xf5\xb1|@H\xb1K\xc3xR\x1a!\\\xc0\x8e\x04Q\xf0*\xfdq\xdbwjS=R\xc1\x0f\xcaw\r\xa1\x11\xf9\xc9TB&\x97'
        b"\xc6\xed\x9c<\xfa\x13\xac\x10\xfc\xd1\xe4\xcf\x12b\xbb'?\x95\xe2\n\xcb1EC.x\x8b\x8e\x1d\xbed0\xe5\xce\x82)\xd0\xf1~\x8c\xe4\xb0\nY\xe0'\xff\xe1A.\x8f\xf0\x8e\xa3}\xce\x8b\xdco\x91\x162m\xb5"
        b'B\xc7yGp\xb8\xa5\x9b\x1f\xe3\xf6\xd4xw\x83\x19E\x10}\xfd\x89\x14a\x8b\xd4H\x80\x84_\xc9\xdc\r\xd3N\xef6\xcb\x9f\x84\x8e2\x8c9\xf1\x00\xabWh\xbcKJ\x93Um\x85?\x97\x89\x8a\x91\x18\xd8\xe3\x0b'
        b'\xfa\xb2\x1e\xe9\x16\xe83\xd6 \xe3\xc7\xcb\xe2\x94\x00\xbf\xf6_\x80!\x8c\xb0\xecKrv\x03g\xfb\xd9g\xb4p\xd0\xa4\xa7\x1c*pC Dc\xael\xeb\xe9\xcc\x90$I\xf0r&\xc5#\xa1\x88(\xe2=;\x0e)'
        b'\x19\x12G\xfc\xe0\xa6\x7f\x0c\xb3\xce!9"\x9f\xd0\x99l:59\x9c\xb6\xea\x11\x0fb\xc7&R\xf4Mg\x08n\xfc\x81\xaf\xd0\xe6\xb1\xba\xeb\xff2\xda\x07\x14\x04\xe4Bn\xbd\x9d\xd7\x98\x02\xa2\x90\xda\xca\xac\xd7\xec\x07'
        b'\xef\xf5O\\\xaa\x11\xe4lt\xefj\x10\xd6AhJ\xa5`\xd8\x99\x85B\xe3x]?\x83\x80\xcc\xabP@\xc78\xb2\x1a\xcbO\xb0\xe9!\\\xb7\xc7\xa8\xe9\x9b\xc0\x87c\xc3\x0c\x99\xb5\x0f)\xbcg\xcf;\x19?_\xde'
        b']\xdd\x18P\x8c\x89=\xa1\x85pxmU\xf2\xb7\xdc\x1cZ\xbc&sZ\xca\x0cX!A\xdb\xfarH\xe7?E;\xa8\x11\x15j+\xebaE\xc6\xf1\x15\x17\xed\xcd\xf7\x86m+s2,J\x1bN\x98\x94O(a'
        b'\x98\xff[\x95\x94\xb4\xe8\x00#\xc3\x1d\x11\x84\xbbzu6\xbcc\xbfv\xb9v\xf8\x81\xbf7\x07\xef\x97\x04} 1\x08\xf5t\x85\xb6\xbc\xa9\x17\xfa\x80\x94\xad\x0by\x8d\x0fD\xa5j\x95\xb9\x8a=\xff\xf5\x8a\xc7\x10ws'
        b'\xe1\x17l5\xffmpAi\xd7\xe7\x89\x06,\xda\xef`\xddT,\xc3\xb7\xd5\xe5\x16\xf9\xf4\xd1ytb>\\\xe4\x90\\\x9ekT\rv\xa1\xfc\xb7\r\xf3\x90\x08\x9f?\x1b?D\xee\xbe\xa1Z\xa3\x01dp+\x9c\x1d'
        b"\xf2.\\+\x10\x89/.\xd2\x90\xfc\xf5A\xf6\x91\x8b\xdb\xcc\xdb'\x0fh\x83$zV\x90\x98\x0b-4=\x84\x83U8F\x15\xecq]\x92\xfd\xc0\xb6\xb8\xd3\x83\xce\x81\x10c\xbb;ZxM\x91\xa9\x8f\x9a\xe9\x04\xd0"
        b'Bv\xbe0\xc2.\xec\x08b\xc7[-^1\xac|\xed\xa2tN\xe1D?}j\x19\xac\xba\xc0\xcfQYs\x98\x88D^L\xca\xf5[\x91\xbb\\<R\xda\xa9\xf3I\x9e\x92\x86o\xdb\x04m\x90\xe6F\xf3{\x9e\x86'
        b'?\x9d\xb1r1!\x8eIZ\xe6`\xba\x0eK\x82:\x80\xaaT\xeb\xff\xc0\xa6\xb5QAR\x9bTfM\xa4\x8b\x06@\xaaq\xbb\xf6\x19\x94\xdf\xfbg\x89-<i\xaf\x0fZt\x82\x93\xdb\xe4\xab\xaf\xd3\x8d\xeb\x14}\xbe'
        b'R7\xa8\x8b\xdd\x97\x93h\xad\x8f\xf9\xddT\xc9f\x7f\xf4\xf8\xa9\x07\xe5\xfc\x01(\xb5\xef\x8b/$\xd5\tv\x914\x9a\xf8\x01\xa6\x80\xa2\x02o\xc5\\`lL\xdd\x9bd\x8c\xcf\xd1\xcb\x99\xf1UlcD\xafk\xd2\x97'
        b'\xc6\xce\xf1\xd0;-1\xae\xb6\xc3\x0b\xcc-\xf3\xaf\xbb\x8e\xc05\xc4\x1e\xbew\x9d[\xdbF\xd6\x8e>_\x127)\xfd_]\x10\x87+\xcc\xe2\xcaD\x97\xd9\x83\xb7\xd13Z\x87\r\xf1e\xb6dp;B\x94\xae\x92\xd1'
        b'\x04\xdb\xe8\xdf\x11\xac\xe6G\xf9\xef-\xc1\xc5A\xa0\x18\xbb\xed\xfa\xef\x80\xe2\xf8qe\xd8\x13/\x8e_\x16\x0e\xfd\xb4\xaf\xfd\xee!\x95~\n\x07\x9d\xfe\x92\xb6\xeb\xd0\xc4\xf9\x8b\xe9\xb5\x92\xf0\xff\x171w\xd8\xad\x8c^\x0c'
        b'R\x8a\x06\xc4\xf4\xc3l[nd\xbe\xf8\xea\x8d/\xefd\xddz\xed\x89:\x92\x05\x1ce\xbd\x87I\x0e\x068%\xa0{Tk\xbe\xec\xdb\x18\xfb\x9c\xde\xde?7\xbd\x91\xf7\x06\xf7O)Q\x10\xdfojg\x08\x1fR\x03'
        b'\xd7\x85\xe5\xd2\x15\x0b\x96\xeb\xba\x13Q\x80\x1d\x17c\xd1o<l\x94\xb8\xa9LW\x99>\xaf7\xb1\x8d:o8\x96\xb7\xdd\xc8\xdb\xa3\xa2\x9eS\x81\xe4GN\xe9\xd3ZR\xa1\xfa\xdf\x0cN\xe2V\x0b\xd8\x96\xfd=\x91\x9a'
        b'\x84\x81\xcd\x80\xaf\x97Y\x04G\xd2\xe7\xbcb\x83\xe4\x11\xb5r\xc7q\xab\xfewf\x94\x8clG\x9e]b\nq\x17\x1d\xe7\x1b\xc1,\x8a!\x8f\xcf\x8f\x00a\x11\x1fc\x84\xff \xaf\x8f@E\xd2\t\x07\x9b\xc1\x07\xe7b'
        b'\x85\xbc\x8e\xd3?\xf1\xa7\x83\xd2\xe07\rs\x9c\x13v*\x9d\xb3\xd1\x93\xdd\xfe\x08A\xc8\xf9w\xb5&g\xf2\xce\xe0WX\xcb\x0e\x8c\x16\x0c\xc4\xfd.\xbf\xa6\xdag5\x08\x10\xf0\x93\x03Y\xcb\x03\x163\xa0\x92\xa7\xe3\xd9'
        b';O\nDG\x05F\x10\x8b)zK\xc6*\x19\x16-\xe0\x92|\x1d\x03,\x88\xfb?W\xccS\xd7G\x813\xdd-\x92\xb1\x82\x87\x0c\xed\x0b\xfd\xe3:\xf3\xed\x97<rn<\x18MDh-\xc6TB\xeb}#\x03'
        b"\x03\x16Zm\xb4Zk$i\xf7\xf2P^\t\xa4\x86\x87^]\xbe}\x9a.\xee\xb0X'cG\xf5}\xca\x8d\x17\r|\xb6P1y\xea5S\xac\xd3\xd5\x10b\xf3W\xe9:S\x19)\xe8\xc2\x0c\x12.C\x1cpB"
        b'\x7fm\x9d\xe6\xbdu\x1ctIz\xc4\xd0\xe2$[\x8a\xc0\xc3\xbeN\x19\x1f\xe2\x86*\xb8\x16\x01 2_Wa\xfe)\\\x8d\xc3\xbf\x9c\xb0D\x19&r\xf8\xdf1H\xa8\tE\x10\xf1\xfcO`,\x0c1\xc3L\x8fB'
        b'\x97\x1d\x96\xacOV\x1c\x99\x0eB\xdc\xb5\xd3r\xae\xcc*\xae\xb3\n\x8d\xac\xd1\x07\x1d\x90\xcaD\xab\xd9\xa3np\xba\x9e\x9a\xec\xb9\x9a\xa8\xa6YI\x1e\xd54\xc4\x9fZs\xc2\xe9Q\xf2\x90\xdaF\xa9\xa6\x91C$\xab\x13'
        b'\'\xf8\x10\x81U\xae\xa5z5\xc6"\x9f\xad\x176x88\x8b\xfe{\xac\x1d\x194\'\xde\xc4\xf9\x16\xdc\xe7\xafu\x9d\xc5\x91@\xd2\x0b\nX\xce\xdc\xf6\x99\xeb\xd9\x19\x998\x14\xc8\x10\xd4(\x97\x0bDV\xb5\xb9G+'
        b'O\xac\x0e\xe4\x87:\x04\xf0\x1a\'\t\xe6\xb6J\xeeo\xb3k\xfd\xe85\x8fT\xb2\x97F\x12\xa5\nAwY"o\xc2\xfeC\xedzN\xd1@\x80\x9e\xbc\xbf\x1fV\\]S7m#\xb8a\xa2\x9c\x8d\xdb\xe3\xf5\x17n'
        b'\xa1\xcan![?\x0f\xb7B\xef8\x91\xdf\xfc^\xb5\x8cQ,\x1b\xd2?\x8e\x95A\xbc\x1f\x98=\xe4\x85k0\nyX\x809P\xb7_\xe7\x85\xb9u\xb18?\x05]f\x1a.\xf8\xf4Q\xa9\xf0\xd8\xe5\xffx\x07\x88'
        b'\x0c"w\x89\xf1\xee~\x1b\xc8\x82\xbb-\x8a$`\x89<\xd4\xf6\x97\x06\'\x9f\x7f\xca\x8d\xb7\xe82\n\x10&\x00? 4*y"!\x10h45\x1b-\xd0\xbell\xcf\x00f\xbf\x00\x0e=\xb3\xb0D\xb6$y\xa7'
        b'y\xbc%0\x07\x0e\x8e\xb7\xe2\xb3{^\xa5\xa4=\x97V{99\xe6<\xa4\x8b\xd4Q7\xee\x13\xfax\xf1#,\x02\x9a\x91AH\xf4\x15\xba\x15\x86c\t,z:\xe8q\x9e\xee\x8d\xf4\xce\xaed\x9e\n\xcc\xd2\x87\xe7'
        b'w\xa9O\xce~*\xc3Q\x8a\xd3\xd7\x87aD\xd1\x03gvI\xfa\xc3<\xfb\x99\xe1\xa9\x9f\x8c\xb5\x019\xd7x\x88\x9a\x84<\x0fg7\x03t\xfc\x93\x811\xe7Y\xcc\xef\xb5\xb7a\xfc%\x87okE\x04\x9a\x08Q4'
        b'i\xff}8\x89\x8bM\x0c\xb4;\xf5wd\xd9\xf1\x92\xb9\xe3\xc02t9\x10\x1f+,GI\xce\x98\xcby\xdf$\xad\xf3\xe0\x0f\xb3\xc1%$Hw\xd0\xc0T\xefR\xbc\x17\x84t\xa5:\xd9=\xf0\xa3\\\x1e\x9f\xbd|'
        b'~`\x83_/\x1b\xed\x00\xa2T\xa9\xdb\x894`\xddfK7K\xb96g\x03u2p8\xaeldk\x01\xd5,\x1a\xef]\x06\x85\xd5\xa32\xa0od#\xdd\x0c\x87\xf3\xa07\x1e\xf9\x02=T\xcc;N\xa1\xa0\xa3'
        b'Fru\xd0\xf1\x99\x9dT\xde\x8cl\xe7O\x03\xf3y\xe5\xecd\\\xc1\xda\xb5\n\xb9\xe1$\x16.L\xa6J\xbbL,a\x80\x81\x9d\xee\xe8X\xef=X\xd4\x86\xc8f\x88\xc2\xd2\xaf\x91\xd6\x90\xf5X\xfasX\x1e*,'
        b'<\x88\xda[3\xb9\xa1~4\x99\x9bY\x94\x18\xc6\xb4\x07\x16\xc3e\xdbS\x95d\xd83$Kg\xca\xa3"\xa4\x00/\xdac\xe1\xfe\x11\xde\xb0\xb9\xc4-`\r\xef\x7f\x84\x9e\n\xe8k\xd2\xe1\x19\x97UV\xc2\x1e\xd5\xaf'
        b'\xd7\x91\xfaOt\x81\xf8\xf1e\x18_*\x86\xf54\x867\xf6\x97\x8e\xa7\x07\x9418v\xb2B\xabh\x06\xd2p87\xebpaP\xa1*4\xa8\xb5*\x08\x00\xd5x>\xef\x1a\x19\x88\xef\xa6\xc4\x01.&i\xe8\x15\xd5'
        b'\xa4\xd9\x15K\x02\xfb\xac3\xc4)\nqH\xdc\xf3\xf7m\x97vs<\xad$\x9f\x80\xac\x17\xd6G7E\x94\xef\xbb5\xe9L\x9a_\xb7\n\xc1"B6\xe9\x07g\xa1T\xe7VQA\xa6\x8d\x86t\xd1\x8e\x93*\x0ft'
        b'W\xfec\xcd\x05\xcdy)\x1f\xb6<\xb3\x81E\xd5\xcaNx\x19\x15Clr\xd3\x9dC\xef,\xf8\x19\xbe4\x90*\xa8\xc5\xd6H\xe3H\xdd\xbay\xe8fY8;$TK\xe9\x83\x91\xea\xe1\x85\xedn\xaf\xc0\xe1N\xf0'
        b'\x12\r\x9a\xbdQui\x01\xa4,\xeb\x7f\x8c\x05\x87\xca\xf4\xc2ON-\xc4x\xafE\x06\x13E\x8f\xf6\xa3\x12.\xef[w\x91\xf5\xd0;-^\xfe\x99\xeb\xef\xd3O\x88\xb9\xc3\x1ar\xc3\xb5\x99$\xb3e\xcbv\x14.^'
        b'\xc9&\x07\x0f\x8di\x05\xe0\x1b\x00\x04\xa85!\x87\xedy\x0f\x8a\xdd2\xb4\x99\xa7\\\x02\xf5\n\x95\xcdr\xbd\x93Z\xb6#I\x9d.\x86\xea\xf3C\xa6\xf51\x7fj\x89n\x12#H\xa40]1\xceO\x12\xa3X5\x8f'
        b'mZ\x9c"6_0o\x17|\xa0\xd5\t\r\x94\x8cQ_j=\x15\xde\'\x08\xff\xbc\x9aX\xeec\xa7\x07,0c"\xe3\x88\xdd\xdd\xb9\xf8\r\x1c\xdahw\x90+0\\\xcdt\xbad\x96\xd9\xdcV\x85\xa2B\xa0\x06'
        b'a\xc6\x99\x18\x87-\x98c\xdffk,\xe7\x9c\xb3\xaam\x05\x82<\xee\xa0\xbd\xd0\x81\xbc\x00\x9b\xa0c{2yNg\xee\x94\xab\xddT\xa8\xfb\x0c\xa4\x97H\xb4fN\x87\xb0z\x1f\xb6\xb0<\xefS\xf7\xff\xba.r;'
        b'0\x97`\xe66\xf8\x86\xc8y\xaa\xd7\x94+3\xe7\x9d1\x89\x92\xc3\xa0\x05\x83s{\x981\xd9\x81\x8aV\x8e~\x7f\x14\xfe\xd3+-\x1fI\x06[\xa2\xea\x9b\x06\t\xe3\xf0\xb4(\x1e\xc06\xab\xb6\xae\xbe\x0c\xa6N\xe6e'
        b'\x1b)c\x1e\xbd\xfc\xa9\xc3\xec\xf3\xe5\xb4I\xb6M\x88,\xa4b\x85k>+h\x8f\xc5\xb5y\x00\xc3@Y\xe71=\r\xf7\x99\xe6\xa2\xa5A\xcc\xc9\x8f\xfaE\xfb\x85\x10HL+\x90\x00\xf5\xc4Z\xe5^\x88y\xb4H'
        b'}j\xa5\xe2C8P\x10$\x8bC\x8d\xdf\x8e&\xbcF\x0e\xb1\xacc<d\x8f\xb1<L\xa4\x99\xdaoy\xae^\x9f\xb5\xd5sqlv+fge\x9d\x18\xb0\xf2x\x0cA2N\x0b\xc0\xf1\x90\xf8\x90\xae8\xc0\xb7'
        b'B\xd2\xb9\x00<*\xd6R"\x02\x8dx\x07qSj\xda\x8c\xf0\t\x9f2\x00oG\xd4\x1b\xd44\xec\xf7k\xd4B"au\x8eE>\xc0\xd8\xa3\xea\xdb\\\'\xef\x07\x1a\xcdC\x0ez\x1d\xed\xce\x84Q\x1f>\xa5s\xf0'
        b'eD\xd9\xddj\x9d&\xcd\x98\x82\xc6\x8f\xd5\xe0<T\xe2\x9fF\x8b\x1a\x84m\x83\xf9\xaa \x17\xfd\x8e\xceI\xb3\xcc0\xf26\xaa\xd0\x16\x1a\x9f}7N\xaa_8+:\n\xf3\x04J\xf3\x1ev\x8f\xdc\xacH\xde\xbc\xe9'
        b'B\x8fjx\xeeo\x99>>\x9b\xe3na\xd9\x11\xad^\xef\xb1(\x14q\x0e{\x82\x18s\x85\xc8(t\xe14\x0b\x98F\xab:\xe6n\xe1u\xe0R!\xef\x13\xa2\x98Lp\x89\n\xe6\x05\xe8&nq\xbd\x16\x0e\xc1H'
        b'oB\xb5\x9c\xa8t\xc5ZV\xf8\xa2\x01\x11\x8e>\x0f\xb9Y\n\x11\x087\xbe\xd7\xfft\x8a\xaaa\x8dm_\x85\x92\xdfb\xc9g\x00\xc3\xad<\xff\xe9\x9fC\x8bY\xe9!\x9a\x0e\x89\xa0\xe3?\x1b\xa6\xc9\x91\xdb\xec\xbf2'
        b'\xa5\x11\x1cY*\x06\x97f\x0c#\xe8\xc1\xd8U\xaa\xedh4`Ke\xc3\x0e]\x1dF\xeb\xfam\x8f\x9e\x91E\x94\xda\x05\xfa\x1bX\x84\xb0\x03\x937\x11m\xb0\xf4\xa1a\xe8D\xa8 \xed\xbf\x8c\x83\x16\th\xb6C3'
        b'K\x9c\xa7\x14t;\x1b\xbb\xe9\x084"\xe4\xde\xdb\x16>\xb4r\x05\\\x01\x16\x12\xa6\x8d\x10bE\x15N(\x9a\xb0\xcd\x81\x7f\x97\xc4\xac\n\xf4\x01c\x96\x86\xd9\x9cm\x1cU\xbaM\x04\xe4\xce\xa80\xb5\xa61\x97S\xa4'
        b'&f\x03\xd8\xd6\xbd%\xc6(\x95\xaelo~MT\xab\x19In\x9a[C\xcb\xde\xd2\n\xbe#\xd1\xb4\xc1\x7f\xa3@\x18B\xec`Cq\xd9%\xfc\xca\xa1\x8f06l2\xcbF\x11\xcd\x92g\x07gP\xfb\xc6bB'
        b'\xb3\x0b\x99N\xb4\x8e\xa7f\x97\xba!\xb5\xce\x8e\x9c{\xc4\x98(\xf9\xb5\xd9?\xc3\x12\xc7\xf4\x96\x1bEA>\xf6g\xabN\xf8\xe7)\x99\x91W\x10\xc7\x8f\xef\xc28\x07\r/\x11#\xaa+?\x98OFU\x0b\xdc\xf1\\'
        b'\x0b\xbb\xaf\xf1\x15\xa2\xa8\x1c\x1f\xe6\xad.\xa0\xe5h?4t\x02\x87\x13\xbc\x7f\xe3\xfa\x17\xf8\xe9\x0c\x1d\x93i \xcd+\t8f\x11\xcf\x02c\x14\xdf\xeb\x9c\xc1rQ$\xbc\xe3\xadR\x82\xa1\xa6\xbf\xf8\x12_Iw\x14'
        b'C\xa5\xb9\xd2\xc1[\xca\x90V\xea\x95]g*\xb10\xb81\xb8XN\xa1hLY\xfa\xd0\xa1`\x1b\nZv\x06\xed\x90\xf9\rV\xfa\x9c4\xc8\x9e:AU\xa0\xc8S\xe0\xe5\xacN\xcf\xbf\x94f\x96\xebW\xef\xf3\\'
        b'\xc4\x01\xf8D~\xbeS\x99#\xe7)\x84\xb1\x81#\xad\x9e\xe3\xad\x01\xbe\x1d\xb7fd\xec\x04m\xe0i\x83\xa3\x0fyF\x873\xef\xbe~q"\x00\xe1=b\x11\x87\xab\r\x1b\xeb\xf5\xd8\xba\r\x06+0.\xf4x\xbe\x0e'
        b'\xefHj2\xb5m\xfdQ\xbb\xb8\xd8\xa0\xf3x\x95\xbe\x06\x8a\xd1\xab\xbf\xef^\r\x86\x81\xc0[\x0f\x05\x94\x92\xe6\x9e\xb0k\xdc\x17\x8c\x1b(\xea\x85rW\xb3\xaf\xe4\n4Qk\xc3\x14\x11tQ\xda\xb5\x83\x0e\xa4\x8f '
        b'\xb7\xfb\xd6\xd6ez\xb2\xd2\xd8\x120\x8d=\x93|\xdeHl\x079\xb7\xcfK\xe2\xe1?U\x1b\x94zZ\x8a\xa4U_\xb7y{gh\xb7\xb2\x8f\xae\x03V\xab%\xc7\x8a\x08\x8a\xac\x00\xecoR\xa5@\xb3\xea\x9a\xa4\xae'
        b'h\x8e\xb1\xe4\xeb\x0c\x17\xee\xe5y\xf56\xd0!Tv\xdf@\x95*\xe8\xbfz\x12\xf1]\xe6aY\x9b/\xfdN\xc8iu\x99OF\xc6*\x98\x1d\xe9\x94\xad\xa3X\x95.S\xa5\xbf\xb3I\x86"\xf2\x8f\xeb\xdd\x14?1'
        b'|\x86{\x82w\xff\xcc\xd8W\xbf\x03\xe8->f\x1c\x14\xfcs\x8a(\xeb\xfa\xb0\xc9\xfd\x92c<\xa3\x86\xec\xe7\x1c\xa7\x11\x04\x10\x06\x8dm\xbejP\x19\xf8e\xd6k\xc6\xfc-,\x86?Q\x1c~\x97\xd1\xae\xe5\x02\xa8'
        b'\xcfk\x1a#\xc3PR\xcfd\x9b\xb9\x81\xacM\xe7\xa9\xe5%<\xa1O\xbfI\x92%\xa7\x16qK\x91\xbb\xaaa\x7f\x91\xa5\xcb\xa3}\x19\xf9\xafi\x9e\x1f\xc8\x14\x0b1\x84Kl\xbd\xcb\x7f\xc6^\x04"D,\xd2X\xe9'
        b'\x1a\xf7\xac\x8a\x0b\xf5\x13\xdah\xda\x94\xbc\xbd\xc6\xb0\xd4\xfd"*kMf\xca\x9fe~\xd3\xe6\xdf\x00\xeb\xf8B\'\xee\xae\xf59d\x12&\t\x15F\x0ex\xe5\xcf\x13\xdf\xc9\xe2\xc7\r\x0f\x8dy!\xe0D\xd7\x13\xfb\x89'
        b'\xe4\x7f\xf4\xb1\x03\xbfR\xb9\xaa"\xdej\xe4\xa9]\xb4\x05\xdb\xfe\xa3\xb7\xda9\x99~\xf8h\xab6\xedu\xf7X\x9b\xefM\x84`\x8e\x17p8\xe6{\xac0\x96\xfc\xd8\x1c%/\xe7\x8f wL)K\x8cb\\x{'
        b'OD\xc8\xd5\xdcG\x91\x9f\xe2\xe3\xb4\xcc/\\\xd6\xf4u\xe7\xf5Y\xfeU\x90X$\xac\xb3\x89\xf3J\xe2>\xb05\xa1\xe0:\xfa\x0c{\x87\xbb\xe2n\xb6\x07\xfb\xc7\x97\x01\x9a\x97W\xa9R\xdeR\x9e\xbd\xfa\x1c\xdd\x1d\x93'
        b'G\xc4\xfc\xf4\xcb\x91\x1cw\x1a1\xe6\xe1d\xb4\xc1}R\xe9\n\xcc\xc3g7Gd\x03\x8c\xc7\xc8[\xc2\xbe\x83\xed)\x83\x0f\xa9\xef\xc3\x16\xf7\xef,f\xd6\xe4n<\xa9\x06\xd0?#\xab\x90\xf0\xb4\x05\xb5\x8d&\n\xad'
        b'?\xab\x92\xe2\xbf\x04\xe4i\xa80<\x1a\x88J\xe0\xc2\ty\xf8\xb5\x9c\xec~^\x01\xa5v\xec\xb3\xfc\xb9\x07\x02\x9a\xb3\xea\x8b\xcf\x17\x8e\xd3^\xb9\xa8K\xa8x\x97,ib\x8f\xad\xe2\x11y~\xaa\x9f\xf2?\x8c,}'
        b'j\xad\x97\x93+f\x149m\xca\x0e\x17\x96\xadU\x1f\x83\xb5\x1b!\xd0O\xaf\x1f@^\xeaPQ\xc4U\xad\xc1\x8a\xdb\xfbf\x8b\xbehB\xa9\xa1\xab\xe6\x04\xba\x82;\xb8<\x826\xc4\x93\x80\xf6\xcaV\x17ilU&'
        b"\xd7I'l\xe2V\xc5\xd7Y\x1d\x1fl\x06jO/\x1e-]\xb3\xdc\xb4{\x1d\x9bq\xb8C\\#w\xb8\x85\x0b\xdbY\x9aa^)\x8e\xfcs\x15\x92\xcf\xba\x7f\xdc\xe8\xabm\xd6\xb8\xc39\xd1S\x164\x955\xf7\x04"
        b'\n\xaf\x97H\xfa\'C\xa9\xa5Lae_"\xa9\xfb\xc3[\x1e\xe7`\xd9*o\xda\x82r<\xae{\x9aVAWn\x08oA2c\xbf\x12\x85p\x15\xab~@\xf8\xa0\xf2&MrOY\xc4\x9c\x01\x8a\xd8\xde\x80\x8d'
        b'\\\x14\x82\x03\x93\t\xa0\xc7\xdd\x11\x16Hk\xc5\xe6\xce0y,\x16\xfb\xa7\xfb\x03tX\x96A>Yp\x8e\x81\xa2\x96\x8aKh\xdcO$\xe6\x1e\xa6\xe3\x1eN\xac]\xc6\xd2+\xb3M\x0c\x97B\x94;\x06\xdd!mC'
        b'U\xd4F\xeb\xe6O\x11\x8e\xfc8D\x7f\xf1\xfd\xfcD\x19\x1d\x14/\x0e\x89\x1eyg\xc4jmI5\xa9\xb6d\xe0\xdd|\x1cc\x02\xd4\x02\xc1a\xc9x\xcf\xb5\xf3\xf4GD\xe9)&\x02c\xf9\xd6\xee\xf8\xedX\x95\x95'
        b'C\xd2I\\\xc9XX\xfc\x94\x8dkjX\xb6\xeft\xb5 \xc9\x99\x8f\x8c\x8a\xe9|\xef\x9e\x11<e+\x99^\xe3\x03\xc1\x00S{\xf1\xa7\xc1\x82\x86\x17\xfd\xa7ew=;x\xb2\xc8\x1b\xdcA\x8d\x0f\x0cT\x12\x0fS'
        b'\xa3\xcd\xba\x1f`\xc8\r\xd7C\r\xa196s\xd4\xa0\x9aGt\xc9\x87\xc5\xd7PW\xb7p\xcc3hq\x9b\x1e\xb0\xdb\xd7\xcbp"\x902\xf6\xef\xcc\xc9\xef\x0b\xee\xec\x9f\xaf\x9bB\x87\xca\xf9J??#I\xef!\xdd'
        b'x.\xa7\xd3\xae\xf6\xacf\xc6\x9e\xec\xdb\xc5>\xf66f\x91W?\xfc\xe9%~\xef?\x04\xbe\x14F\xfc.\xc3\xdf\xc6\xf0#\xf3@\x8d\xd7\x94\xd80\xb1\xd5~7a?\xb5\xd4<\x0bW]\x9fm0Z!\x9c1='
        b'\x8f.\x05\xd8\xfd\xd2\xb0\xff\xba0E3\xe3P\xe6Hr\xe5X\xbcNq\x8d\xcb\x0f\xb0D\xd7b\xc5\x9e\x99\x87\xd4\x93\xc9\x97\x89D\xcd\x19\x1d\xf3!^\xe6Y\xb2A\xdf\xeaR\xbd=\x99`\xf2\x9c\xd4P\xc2b\xe4j'
        b'\xf6\xc8\xc3\x82\xa6n7\x8e\xa4\x80V*7\xc0Rf\xcad\\\x02\xc6\xa2\x10\xdd\xc0&\xa8t\xcb\xd0\xa9Q=\x9b]g\xac\xfc\x9c_\xde\x0c\xe4\x16\xeff\xc7\xe7\xbfZ\xd6\x16\\\x9c\xaf?\xbe/c\xcejS\x9c\xdc'
        b'Tu\xba,\x8bs\x9f\x84y\xbfy\x1ei\xddo\x86\x9e\xc3\xf9X\x04{\x99Z\xb9)\xb5<\xf8\xfa\x93\xc3D\x87\xbbx\xa9g\xe98l!{\x8a\x9d\xff\n\xfcZ\xae\xbbl\x8cw\xe5\x9e-Fn\x07O.\xa0='
        b'\x18oX\xbeC\x03\x8aME\xf4\xe4\x07O\x98a\xfb\xb5\xc3\xad\x83\xe4\xc0X\x0cX\xbe<aL\x84\xd15m\xda\xbd\x1c\x08\x07i\x1d\x160LL\xf2\xc8\x83)EB)\x8e\xdc\xe6l^9E\x1eM\xa3\x0c1\x99'
        b'$\xeaM3Q\xd7\xe6\x87\xc7q\x17:cpf\xb3S.C\xbb\xdc\xb7I3\x15\x9b\x9b\xd5\xa42y\xa2\x0c(KyX\xf7\x8aMbX\xdd\xf9\x9b\xef\x81\xad/>5]\xaa\x0e\xaeNvA\xc1\xa0\xf67\xd3\xd2'
        b'\xa1\x80\x07\xc3\x1a\xbe*\xa0;CO\xe8\xee\xd7\x08\xaf\xef_\x93/`\xe6e\teRN\xb3\xb5v\x8bl\t\x02\xebu\x83G\xf3\xa3I\xc4VR\x9f\xb2yE\x92\x96\xcci\xf1\xd6\xeb|\x8c"\x9a\xea\xc9\xb7\xae\xcf'
        b'b\xb6/#M\xc7\x1e\xf0\xda\xc7\x95\x18\x83\xcc\x0cC\xd8C\xac\x1cW4\x06\x99\x04\xe0\x04\x19\xcf\xa4\xcd\x1a\x84\xdc\xaf\xe9M\x16\xc87;m\xe8\xa1n\xa3\x93*&\xf8l5\xbf\xc6Wm|\x86x\xc0.\x0fW\x9e'
        b'\xff\xbd\xc4\xad-MQ+\xfa\x95\x97\tL\xefu"\xfe\xd9>\xfap\xeb\n\xdc\x0f\x81(kY%\x97\x95\xda\xc5\x7f\xe1\x0eM$\x10[z\xc5k\x14@\xa4\xc4\x92L\xb0,X\xf4\x9c\x8c\x0e\xb7\\\xc6Qs0\x8d'
        b'\xc3s\x8d\x97"\'q\xc6@\x88M&\x03\x86\x08x\xd3\x19\x03\xd0%\xd8\x85\x92\xfbA\x98\xf6\xd7CA\xbc\t\xa5\xf3\xe7\xf3\x1a\xbc_\xc0\x98W\x1d\x95\xaa\xea~\xbc\xb0\xfaw\xc0bK{\x81#\xc7\xae\x85W\x15\xe8'
        b'\xb9,6 \x99\xf2\x10\x82m\x88["7T\x9d\x83\xbe!z\rv\xa5\xd3\t\x07\x8d\xab\x1e\xb0#h\xe2\x9c0\xd1\x1e\x1a\x04\x94\x81\x8c\x9bzU\xaf\xfe\xe33\xa4V\x12\x1dybhs\x07\x12{\xc8\x1e\xb0\x93\xed'
        b'!\xbeI\xa5\x88\x94\xc9\x87/i\xa0n\x9c\xd4\x84\x9a\x18q\xabs\x0555E\xd6\xf3\xa6`!_$\x0c8\xea\xf4\x03\xbd\xb5\x1fp\xd0\r\xc9\xf8\x0fe\xa1cW\xb5a=\xc5\xcd\xec\x9d\xcfC\x8ciy\x0b=\xea'
        b'\xaf\xdc\xd0\xd9q\xdf~v-\xe0\xf0B\xee\x87\x8ahiInC\xdf\xfb\xe9N]\xe3\xcbq\xf8k\x84^\xf9#\xaa\xab`\xc3\x94y\x9f\xf9\x98\x17\x91\xbe_\xc9I\xf0D\xcd\xbe\xab\xbdQ\x1aS\x8cq\xcf=v\x12'
        b'\xb4\xf6\x9d\x1b.\xa0Ke\xeft\xc2\x916AB\x96G\xb1\xfd\xa2\xfa>{\xd7\xa0\x81\xa1\xc6\x9f\xabY\xac\x83\x87\xd4\x1b\xb0s\x81\xe0\xa2\xb5c:\xcdr\x1f\n\xa9\xad\x95}V\x1f\x97\x06~\xdbh\x18\xed\xa8\x02\x94'
        b'V8E\xb8\xd0\xd4\xc0\x9a\x7fd\xffG\x86\xfdH2\x1dlB\xa5k\x83h\x92^\xbf"\x97\x992\xee\x08\xeb.*\x10\x804\xfd\xea\x15\xbanh\xcf.\x94\xb0\x06<\xa2\xc9\xec0\n\x99\x00\xf6\x1b\xad\xbf\xbb\x9el'
        b"\x93\x84\x89\xae\xe47*z\xbd.1\xbc1\xa2\xd3\xa9\xd1\x02\xa0\t\x80J\xd2q\x0e\x101g\xf4\xfc%\xbb\x96\x0ck:\x13\x9eAI\x03\xe2\\U,\xbb\xf6\x8d\xf2\x06k\xf5c\xc9\xd4}\xa3\x92\xc9'\x86\xde\xb4\xf1"
        b'T\x98\x8cU\xbaE\xa1\x1a\x01\xd5\xbf\x8a\xc9 \x1d\n\xddf\xfd\x05_\xc4\x19\x8d\x18\x99\xea=\xbf\xac\xe2d\x17\xca\x15\xba\xe6\xa3\x00T"\xd7\x92\xb4A\x1cj\xc2&\xd8\x93\x99k\x94s\xec\xd9xbR\xf9\x1e\xa1$'
        b'q8\xf2\x1e\xde\xb4\xfaF\x17_\x9e\xb7\x01"4G\xfd\xcf+\xce\xff^\xd6\x14\xab]\xde\x1f\x1b4\xb7CzA\xd57x\xe0\x96h8m\xca-w\xec&I7&\x1d\xe5%V\x02\xa8\xbd\x1f\xa8\x98\xf8 :I'
        b"\x05t\xac\xe6m4'\xaa\xb3\xac\xc6SJ\x8cc\xa7\xd0W\x8c\x8b\x1aS\xf2\xab\xe0\x81\xdc\xb3R\x924_3\x80\xc2R\x8dQk\x10\xf3\x07{\x0b\x82\x92\x8f\xd10\xa1P\x82\x99\x89W\xdb\xcc\x9e\xe35\xd2\xe1\xf7\x8f"
        b'\xf9qN\x07R\x07\xd5JL<\x93:G\xcb\xd8k\x9a}t\x02s-\xe2\xefz\x99"Ub\x1fg\xa3\twd\x9b?\xa7\x10FB\x14\xa4\x88\xa7\x05\xd4\x99\x03\xd3\xda\xc89#\x84\xb4\xf9hg\n\x7f\xf1\x0bX'
        b'\xe7\x99\xf22)\xc8$(\x13\xa4\x13\xb8MJD\\U\xa5S\x85ni\xf5HW\xfd\xda\xab\xcf\x92\xbe\xe7\xff.\n\x15\xb83\xc1\xf9\x87*\xcex\x08]@\xb6/\xe1*\x0b\x12\xccF\xb2\xf4T\x83+\x96\xed\xb35'
        b'\x98Q\xe5F\x88\xd8\xd6#g\x8a\xe9\xb4p\xa0\xf6\xc0|\xf4\xd1\xf9\xcb\x1e>\x0e\x1by\xa9\\fP\xde\xb5\x01\xfb\x99\xae\xf0D\xf4\xe1\x122u\xed\xa3\xdd\xcfBY\x04\xce^P\x08\xcf\xb4Ed\xaf; o\xc6.'
        b'\xf6\xdd\xe9\xdb\xbb<\xc8\x13X\xe6\xfa\xb0\x99I\xdb\xd2.\xb4\xbd\x93\xe2\x1d\xa7\xb3\xd2\xb0\x9d9\x9e\x91\xc4\xf1\x1b\xed\xaf\xbf\xc5\x05\x1b\xfb\xa7Z\xed\x91b\xb6Q\x91o\x07\xc9\xcc_RF\x0e\xfd\xc2\x99U\xee\xef)\x18'
        b'\xed\xe2\x9biL\x88\xdc\xfd\xd1\xa3\x18Oz\xd4^\x04g\xd7I\xfe_3.\xab\xb6\xc2\xe6\x18\xd2\xa6\x9dqQAG,\xaf\x9c\xebe\xaa\x04t\xc6\xc6\x86\x11T\x0f\xa9M\xcc\xe8\x1b~Y\x16\xbb\xd9\xe5\xc1x\xa8u'
        b'\xd4\x07LCU\xf6\x8e\xechb_,\xe7\x0f\xafA\xcfs+\x1d]\xa0!&J\xc3\xa2\xdd\xa3\x86\xc3n\xad\x03s$\n\xc6L4\xeb\x81n\xc2w\xf5|\xc7 ;]\x01\x88\x02%\xbbS\x02\x86\x84^\xd9Wj'
        b'\x9b\xe3Wp\xe3&\xf1eUE\xe7\xef\xd2\x15Xp\x02G\x15ot\xd9M\x1dI\xa4|\x11k\xeb\\z\xaa\x0f-\xdc\xc7\xf5\xbf$\xd5\xd4/\x07\x1cc\xea\xca\xaf\x05\xa2\x9d\n"y\xc1\x1d\xf7\x81\xb0\xa9\xbd${'
        b'8\xd7\xebiW \x18vTA*\xb6o\xc8\xbd\x9e\x16\xa5Q\x0b\xe1\xc7\xbd\xb3\xa5\xda?A\xb5\x0e\x16\xf5\x86\x8a\x02K\tPT6\x14H\xde\xb6\x19g\x0b\xc6[Pv\x97M\x1b\x90\x8fu-\xe4m\xe880\x8b'
        b'\xd0\x81\xf3\xd0\xd5PK>\x91\x17\x87\x04+\xea\xd1\xdc\x98\x93\x10;]\x0f\xf5\xe4\x11\xaf\xe5\xa6\x02\xe8\xa3\xcc4\xc8\x90\xd9\x1c5\x80il\xe4 (\xd2\x1f\x12>\xben\xa6\x0bF\x19\x1b\xf4\xe5\x93x-\xc3\xef\xc6\xd2'
        b"\x0fm\xbd\x84Y\x8d\xb684\xa5>\xbd\xbc\xc3H\xd4\x12\xcc\x13\x92'\xdf\xbd6\xa9;\xb9\xc7\xc7\xbexa\x83w1F\xd9&\xc6\xd1\x9e\xa7H^\x943\x96\xb4s]6Swq^T|\x1c\xec\xb9\x17We "
        b"\tW\x11\xad\xbd\x06OT\xe1B\x0b\xee\x931~\x16\x91\x05[\xb5\xdb\xe3\xafv\x81*k@\xfbb\x97\x0b\xb6@\xdc\xa1\xc0\xf9\xc2\x89+\tv\xaeR\xf6\xd0=M\x7f\xc0\xd3\xa6m\x05\x826\xa3\xd0'U%$k"
        b'@\xb7\xda\xad\xffk\xef\xe4\xe9nG\x89"b\xcd\xf2\xc7u\xd9\xba\x9b\xb7p\xa7\xfa\xcb\x96\x80w\x064\xb8\x01O\xc9(dG[\xf24g\xd1c-\x9b\xbb\x932|\x1f\x15\xe0,\x0c\xea\xc1}\xd1\x93\xdd%!P'
        b'\xb8\x10\xb4\x92[^\x0b\xae^\x8d"\r;\xcb\xa0\x89A\x07\x0b\xc9\xa0\xc4\x8d\xcf`\'K\x04\x16\xb3\xf4\x98\xedl\xa1\xec\xf4]\xec\xf4 Z\x14\xce\x97\xe2J<\xde\xaf\x84\xe7\xfb\xaf\xa7\xf4\xfd#\xe2\xbf\xd5\xb8\xf0\xbe'
        b'\xac\xc9\xc3\xb7\xaf\xbb4\x83%\x9f\xa8~M\xe4H\xc0\t\xc2*\x05S\xe7\x81\xad\xf9\x96\x9eW8"W\xc9sz\xe0S\x85\x08X\x16l$r\xdf\x00\x91\xe0\x01z\xa8\xde%\xd0\xa4\x89\x9a\x8f\xd8.*u\x8a\x18\x17'
        b"\xa2\x9c\xcd;\xfd\xcd\xa4\x1a\x06<\xc7\x02\xb1>\xb9/\x92\x9f}\x10h9I\xda2cx|\x16n\xa8\x93'\xdc\xee!\xbbZ\xaa6\x88\xcb\x97ZY+\xee?U\x9fU\xaf\xaa\xe3\xd5f\xeb\t\x83\x8f^:,\x07"
        b'\x82\xdb\x04\x01\x8e5\xd0\xda\x97\xa9\xf9\xb0\xe9\x82B\xbf1e\x8c\x17\xd4\x0c\x97\xcf\xdfR\x83\xa7\xa0\x06\x9d\xd2\x8b\xe3\xd5\xde\x9d\xbdD\xa7\x11\xf5<\xaa\xf6\xdb\xf0\t\xaa\xe4\x00S\xcf\x10\x12\xe0h\xd5B\xab\xfb\x93\x96\xf5'
        b'\xc1\xde\xd0\xf0`5\x0f\xe9\xf8K\xb2/\xbb;\xe8Rk<\x85\xf9R\xf4\xff\x96\xd9\x1d\xe4\xee\xa7\xaf\xb2?\x84x\xb4\xf7$\x9e\xaf\xf1\xd4\xf1\x9a\xa1\xb2D\x8b<\x132R\xfb\xc4s\xbe\xf8\xe9\xfb\xf3\xe3\xe2\r\x92\x91'
        b'\x97\x05T\xdc\x968\xcc\xecV-\xfa~\xd0\xe7\xa5\x1d7\xee*I\xad\x90)B\xdd\x9fk\xa3\x99\x88r\x02:\x15nq\x80-\x1b\x93\xc3\xae\x06[uZ\x19\x93\xc2\x04\xc9\x9cQ\xba\xfb\x0b+F\x9e\xcdM\\\xf0\xea'
        b'|\xfa\xb6\x95C\x05\xd5\xddV\x94?M\x14\xddS\xc0K CG\xb5<\x80\x03\xa7%\xe0m\xf5`\xa3\xcdh\xf9\x7fy{\x99\x9b\xd7\xc9\xc7\xda\xf9\xd8D\xd4\x9d\xe5\xc4\xd3H0\x92u\x98\xa7\x85\x97\x1b\xae\xdd\xa3@'
        b'\x80\x95\xc8\x98\xf1\xa2\xdb\x19\xe3\x96sE\x98I\xa1#\xd9"\x1bN\x00[GP\xb6l\xa8\xc3\t\x1c\x13\x85\xbdt\xb0\xcfW}[\x1f\x80\xa4\xa6-:O\xe7\xe5\xda\xe0\xbc@\xb7\x9e\xed \x99\x90\x0b\x8b"\xc3\xc6\xbe'
        b' \xd1\xc0\x0b\x0e=\xf5\xbb\xe8\xd0\x92\xd7\xf9\xb5\xdf\x8euH\xedcf\xc2-~\xf2\xf77y\xa0\x92\xb0\xa9R\x92<d\x90\xe0\xafjL\x02\xee\xa9C\x064\xf6`\x93\xc8U\xb7\xb8\x99q\xd1\x9b^K|\xb9\xa9w'
        b"uBC6\xc8S\xe0y\x9e5d\xe4\x86_\x00lI\xfc[n\x12\xc4\xf4O'\xc1~\xebB\x1c\x83c\x98S\xa6\xc3\xdb\x14\x97\x95Qt\x11d)N\xd0\x9d\x90\xea\n,\xa1\xe9\xd8\x86\x1b\xba\x0c\xb5\xb4En\x0b"
        b'\x1c\xd0}\xdf\xdf\x1a\x16XF\x0b\x19\xc63\x19\x0e\xef\xa5\xdd\xd51d\x00\x02\xc8x\x8e\xe4XsW\xca\xe2\xfe\x01\x84q\xad\xccR\xe0"\x96u\x88\xda\\\x1f\xb1\xe4\xee\x94\xd5\xc6#f\x0bj\r\\\xb8\x7f\xa6\xc3\xa1'
        b'F:\xce\x84\xc9\xc1\xce\xe9\xad\xac\xd7l\xf3\xe7\x99E\xe8\xe6\x16\xb7\x9f\x0f\x9c\xf1\xc4m\xa2K\x85\x00\x8d\xe1\xfcj\xbcJ\xc9VGn1\xa9\xb9\x03\x15\x99Y\x18\xe8x\x94\x0c\x99\x8fzHM\xd2\xbf\xbeR\xd7\xc6;'
        b'S\x0bVY\r\x0f\x16\x11\xedi~\xad&\xd323}Q:\x19$\xe4\xe4\x98uo\xa6ABD\xd2\x07\xfd>\x19\xd9\x04\x91\xd7z\xb4k\xd6r\x86\x85\xa1\x0bUH\xe4?(\xa4&\x84\xec^\xbf\x8e6id\x9b'
        b"\x8a[O\xc90\xf2\xac-@\x08\xb0\x06/\xc5\xc1<\x17\xb4T\xb3wN=\xcd\xcc\x13?\x9bE\xde\r\xdfY\x01\xf5\xbd\x81\xac=\x08\x04kY8\xe8\x07\xb5?G'\x9eOX\x94K\x8a\xa2\xa4TS\xf3 \xf8\xb5"
        b'\x16(\xf0\xbe\x03\xda\xb1\xae\x97\xc9\xe9\x0c\xeb\xe3\x9b\xfe\xe6\xf0\xcb\x84\xbe\x1f\xf9\xfc)\x85\xc5\x83\x06\x04b\xc0U;\xdc\xcd\xcd\xaap\xe5\x88\t\xa0-\xd0W\x9d\x10qG\xa0H(T|\xd2\xfdQ\xdfl\xef\x94wX'
        b'\x87\x92\xa1\x87Eq\xf4\xc4-\x97\x85\x14\x8b\x1aI\x14\x10^o\x90\x02\xd6kd)\xa3i\x10\x10\xaa\x8c-\x97\x15\x84\xcf_\xba\xa6\xfd\xde\xe2;\x8c\xe2\xf4_5\xccL\xa2$\xbb\x98\xa9\x1b\x94\xd3c\x8f\xa7`\x8a\x15'
        b'J\xa2\xaa\x8a\r\xf6\x1eJ\xe7]\x7f\\2A\xc8E\xda\xf4hhl`pZ\xff\xf8\xccHoR7\xbb\xb9a\tZ\xc5B\xcek\x16\x0b"X\xaf$\xa5\x1a\x05\xd1\xf9\r\xb54\x0b\x95\xac\xef\x08F\xed\xd4u%'
        b'\x84\xdcr\x15\xa3\x08\xb9{\xe6\xe0\xad\x19\xcb\xc3\x17J\x9a\x07/@@\xd9R\xee5\xf2\xce\x02\x9d\x8a\x8a\x93q\xc1\xf0o>x\xe1ii\xeb\xa3\xe2\xfbw\x94\xf7\xc2n\xfb_oH\x19f\x83.JE\xd1WQ\xbd'
        b'\xfa\x06\xae\x04n\xbf\xe3U\xa0j\xd8\n\xe6\xdaV\xb0\x93RNP9\xe1\xe4\x85\xb6!U\x06\x86\x01b\x92\x99\x94:\xc2\x18\x11\xe6\x909\xce\xbb2\xd3x~\xe9\x01\x95\xcf}\xbbxbC6\xb4\xd1]\xd9Qgj'
        b'0\xfe\x82&9\xd1\x07o\xd4e[[.>\xdcy\xae\xd8>\xdf\x11H\xb0\xfc\x15\x8b\xbc4\xcc\xd8\xe5\xc80\x91E\xfa,\xb1L\xfd\x87\xffv\xd1<\xa7]\n\xf9\x0c\x18\x83\xc4\xda\xb6\xef\t\x84\xefq\x88fA\xd8'
        b"9|M\r\x1b-\x8a{\x1dK5.\x8d\xcd\x10\x9e\x155\x04\xd6\x19\xad\xde^\x96\x01\xecL\xe0\x16\x90\x01\r{\x0cM\xc0?F\xd1\x01\xdd\xdc\xdd\xee\xbeG'S\x96d\xf4O\x0c \x0f\x1aO<\xeb\t\xcc\x87A"
        b'\xca\x84>Q\tP\x8c\x96\x1a9z\x9d\x0b\x93r1\x16\xf9\xa1\xc7\xc7\xf5\xe6\xb8\xed\x0b\xcfh\x8c\xd91x\xa9\xf7\x9c\xb0\xe7\x94w1\xb1\xc3\x0flw\xf21\x039\xb8\x8d\xbaT\xf9\xfc\xd7p\r"\xe2\xb49u\x88'
        b'\x8bs~Q\x92V\xa3\x0b\xea\x86]\n\xd1D\xc0X0\xdf\xcf\xec\xf0A3\xb4L\x95\xd5\xff\x1a"\x01XRS\xb2\xc6\xd3\x08+\xb9T>\xf3E\xcf\xb1\xb0\xd4YT\xd3QK\x81\xf2\x94\x9d\xb2F\x91\xea\xfe\xf1\xf2'
        b'\xe0]\x8d\xe8\x1c\xeenT\xdc\xdcg\xa7\xde\xc9b\xa2)\x06\xb7\xb5\n\xc9\x87\x99\xb1\xef\x04\xcbj\xce\xc2w\x86\x06\xcbd]\xa2\xfc\xb2B\xdf13S\x85\x16-5\xd5\x83\xbb\x98\xb6F\x1b\t|\x9eQ\xa4\xd6\x08G'
        b"\xa6\xc42.\r\xaf!\x1f\xd4\x89\x82\xd3\xe3w\xc5 P\xeb\xc8\xab\x0c}\x9c\x86\xc6\xe3W\xde\xb55\xd4\\q\x16\r\x86'\xc0\xe4\x8aSQ\x8f31\xd0j\x16\xeb\xcc\x01\x1a\xca\x9f\xd6U\x97\xd1P\xbaZ\xeb-\x93"
        b"&\xde%\x89\xd8Sa\xdbn\x1e\xc9\x1c\xc8\xb8\xd3\xa6\xd9\xb9b\xf8\x17\xe1B\x9f\xb1\xeb\x84\x9e\xac\t\xf3N\xda\xe4\xa5'\xa3()$\x99_\xa8eB\xfd@\xbaXZ)/\xfbP^T\xaf\x86\x03\xf4\xaao\x99\xb6"
        b'\xebr\xc7@)4\xb8\xee\xa0\xf32\xd4\xe0\xf8@\x05\xea\xcc!:{\x9d\x18X\x9e\xd8\xa7dkr\xb1\xa2\xbe2W\xb8\xf1\xec\x16H\xbc\xd2\x18\x1d\x1bJ\x10\x82)^\x06\xb2\xf6q`7 \x84\x92&\xa3\x89\xf2l'
        b'@L\x86\x85Gt\x03`\xe3\x00\x19\xe3\xd4\xe4\xee\xech\xc9:;6\x1a\x0c\xad\x81\x93\xc0\xe4)\xc0nY\xe7f\r\xad.D\xe2?_\x07\x80\x1e\x94\xeek\x1a\\\xa0I\xc7\xf1tq\xaf\x14\x83\x86m=!\xec?'
        b'\xad\xd7\x7fP(\x87\x80\xf5\x94&=\xcf=\n\xb6o\x02\x8a\xe6n\xceG|Sz\xa22_\xa8P\xe8\xce\x93\xe3_+%}\x0f9\xdb\x85\xc6\xb0\x95\xc2y\xd9\xfd\x80\xc06\xb3w\xac\xf0X\xf8\xa3W\xe94\xe8\x86'
        b"\x1f_\x97Z\x8a*\xe1\xfax\xac)\xe5\xb1\x9fu.\x87\xdb\xc8x\xc3\x1e\xbf\xdb\x14t\x9e\xed#X\x06\n\x94\x7f\xcd\x9b\x18\x06zC\x84d\x81x]\x14\x9f\xc6'dw\x1cO\xb0\x94'\x0f|\xa1\xa8<\xdf\xba\xc7"
        b'\xf8\x95m\xac\x1f\x08\x1b\xc3\x9ed\x15Jt\xf6\xeeB\x1d\x8e\xe6\x1fkR\x1a\xa5\xd7:ZvK\x10\xfc\x8f\x85\x8ff\xfb\xa6\xe2\xf6\x18~\x17\x9fg\xc8\x06\xa2\x92\x99\x87\xccM\xebN\n\x9a\xc0\xc5\xe5#\xd1\xde\xb3F'
        b'\x00U\x7f\xa1\xaec\xd3\xae%\xb8\x97\xa8\x85\xca\xbe2\xc3\x97\xd4\xbd\xff\x9a\xb4\xd6\xd7xb\x00\x02Z\x05\xf3p\x03=f\x90B\xf1\xa3{\xfa\xa1&\xf7\x0cq\x8bL\x8a]]\xba\xce;/\xe6\x11\xbfmf\xfd\xf1\xa5'
        b'$\xf8\xa7\xda\xfa\xaeu\xfc\x95\xcaY\xe9#2\x9f:|\x03\xdd\xa7)|\x11\xae\xc30\xef\n\xd6V\x11\x91\x13\xaeC\xc8rA\xf3\xe5=\xa8g\xf1\xa4\xbaUF8\xc8\xef=+Y\xad!\xe2\xba\x1b\xcb\xde\x18\x7f\xda'
        b'\xc9\x8du\xbb\x15!\xd9\xd4\xb2K\x0e\xbdu\x19\xb6\xeb\xab\x861\x82\xc1\xdf\x88\x0e\x87\x06CV\xc7N\xdb\xf4\x07A\x8ed\x14bJ4\x91([\x12h\x96\xdb\xb1\xc2\xb2\x93\xa2\x94*\xbd\xf2R\x18\x95\xdf\x98Eq0'
        b"\x08\xd1\x02\xb7\x85\x1a\x19a<\xa5\xe5x\x8f\xf8\xaa\x00i\xd3\xea\xde\xc7\xc1)\xa1\xd1{\xb5\\d\xeb\xe6hr'\xfd}\xd1\xe4\xfe\xdeR\x82t\xc3\x9a\x8a\xc0\\\xacR;\xb3}f\x0e(\x88`\x13\x8fD\x8a\x8a\x90"
        b"\xa3\x1fd\x802 [j\x88\xee\x1b\xc9\xa0j3\x15\xe4\xb3H\xc5\x84~H+$\xd0\xf0\xc9\xaa\xff}\xdadp~dN\xa2\x94;&7\n\xca\xe3\xfb\x1f\xf4\xdd\x1b\xa9\x89=\xa6c\x00p\xe3\xebr\x86'\xea}"
        b'\x1b\x94H\xbd\x8a\\\x0f\x9bI\xdbI4i\x05e\xcf\\\x99\xebp\x80l\xc7\xf6\x01\xe7\x82\xea\\\x16\xcf@\xf6\x04op\xb3\xab\x15\xbbv\xd6\x9e\x80\x82\xaf5f5\x83\xbav-\xe4L\xff\xc0u\xbf\xa2\xed\x19\x94\xb5'
        b'M\xad%z}-j8L*\xc7\x80\t\t\x7f\x9e\x9bw.\x89\x9fd\xc4$\xfa\xf5J\x99\xb0\x89,\xce\xd0\xef\x9dT>h&\xe0\xd4%9\x00z$\xaf\xafsI?a\xc2D5]\xf2\x9b\xa2X\x80\x8e\x15 '
        b'[\x03d\x1e6[M+\x1b\xdb\xa9\x1aK\xb6g\x81\x10\xa2~\xc5\xb1AcRM\xb9\xd9 \xbb\xa2d\xeb\xa4\xe9\xb2X\xbe@n\x86@\x9b\xcc\x93\xe1\xd0>\x93Eb\xda;\xfabUQ\x1a\x81\xee\x02S\xe8\xd7\xed'
        b'k\xeb|\xb80\xae=\xe2\x8f\xbe\x059\x90\x02\xcc\xe1L.x\xce\xf5\n\x0e\x96\x02\xbb\xcd\r+\x0c\xf0\xbd\xa5\xa4~}\x9eO83\xd20\xdb\xf5%K9\x07\xc3\xcd\x9e\xfd\xe1\xed\xf9\xf1H\xb4J\x93\xe9\x12\x9f\xd2'
        b'v\xb5"\x11\xd3O`U\xf0\xaf\\*\x18\x0f .=\xa4\x03\x9c\xba\x0bpT\x14pzF\xa4\xcd\x15\xd8\x1d\x9b\xd4\xf0\x80\x00\xef\xb2o=k\xa9\xfc2\xbb\x9f\xed}\x19\x1a&\x8d\xb1\x10\xaaAlNl\xf0\x0b\xff'
        b'\x17\xfd~\xda0\xe0|\xc5_\x9a\x13\x86_wV\r\xd46M\xb2\x8d\xd6\xedtl\xde\x05\x97I\t\xfd\x07Jx@\xbed*\xbf1\x97\xceZO\x9c(\xfd\x13\xad\x82\x98?w\xbf\x0cW\x85\xc1A\x14*\x19\x1a\xf9'
        b'\x8e\xdf[\xb7S\xda\x16\x94&P\x10\xcd\xba\x0c{">:\x10\x8d\x12\xa8f\xe0\xc5=\xe9X\xba`h\x83PJ\x88\xdc"o\n\xe7\x04\xa6\x07;1\xa4\xf0\xa41\x82\x10\xeb\x15\xf4\xb6\xdfV\x80}\xebi(\x05|'
        b'\xa0#\xcc44N\xb9uwG\x06\xbb\x81\x0ed\x12)x\xac3\xf1\xc5\x90\x94\xebs\x7fY_\xe9\xbd\xa1{~\xe3~G7\xae\xbb8\xac~5\xd7\x02\x7f\xf7\x89B%\xb5\x9df\xd9\x93\xcc/\xa3\x16p\x18b\xe7'
        b'\x86\xd7?\xfc\xd8\xae\x11\xbf)e\x96\x0f\x04\x07\x89\xf0\x99\xdc\x9a\xdbB?\x0f\xd7`J\xbe\xf1\xc3c\xcf\xa2\xb5\x87_\xa3\xfd\xe6\x8f\xf3\xb0\xe0\xf8ks\xed~\xcf\x14\xfb\x8a\xaf\x9cZ\x1fI4I\xf53\xd7\xde\xbf\xf0'
        b'\xfa\xa6\xdc\xe7\xc8o3\xb8\x81u7f\x94\xe7\xa7M~\xb8v\xc6\x95\x0eJ\x19\x9d+\x92\xd8\xf36|\xcb\xfdA\xa9\x84\x80\xf5\x89\xf4" (@\xe4@\xe4|S\xcb\x01\xe0\x90\xba\x01"\x15s}ZO%v\x94'
        b'\x90<\x14u\x11\xb7\xbc\xab{(1t`\xa8\xa6\xa6\x08\xc1d`?\xb1j\x0f?s\xb9|\x8dv\xb7\x83\x1b\xc81H\x8d`\xb8f\xe9\xdbA\xdc\xeb\xb7g\x1e\xe0,ODB\x90Y\xc1\x8f\xb8\t\xe9\xa3\x8c\x8b\x1a'
        b'\x11Dh8\xf2U\xadB\xe8\x9f\xb22\xee,\xd6y\xb3\xa2\x8a1\xe1H:\xe0q\xa8\xab&$\x96\x80\xec\x05\x8d\xfc\xb7\xb1!\x93\xd1u\xc5\xc4`V\x02\x7f\xed\x14\xa5\xd3-\xfc\xd6\xc8-7\xc0\xea\xb9\x90\xf8\xaf\x13'
        b'\xaa\xa5\x02`\xcdm,\xc3}E\xa5}< (\xd5G\xb42Z\xa3z\x87\xcd[\x02*\x95H\xaa\xe0\x05\xc5\xa24 \xcd\x82\xe9@:\xbfx\xe1K\x8e\xa2\x83\xda\xb3\x18.!)2v\x02\xea,t\x9f\xaf\x9b\x03'
        b'NR\x97JBr9\x82\x13XG\xd5UE\xa2u\xf3\xe2_:~f\xff\x1f\xa9\xe4\xfbjZa\xe4\x84[!\x0c\xeb\x01h\xcar\x99\x9f\xa6\xdf\\\xff\xe3\xa9\xc7h\xc1\xf0\\W5\x1ai\xf7\x01\xf4y\xc5\xde|'
        b'\xe6\x8fN\x82$\x17/\xd2\xe85\x94\xa2\xccM\x8f\xfd\x10\xdb%f\x8f/\xe8\x14\x0e\x0faoxq,A\xe3u\xd9{\xbb\r\xc5\xd0\xb1\xa1\x0b\xeez$\x02\xf9#"5R\xc9\xcb\\\x9c\x1f\x0c\xf8\xae\xa7b\xcb`'
        b'v\x18\xc8;\x07s\xbc\xda\xc4/\x17\r\x00y\x87`\x93\x8a\x95\xdd\xaeV|\xa8!\xfd)\xd4\xea\xa2\n\xac\x97\x16\x9d\xa4\xb2t3d"P\xef6\xa9\x97\xc7\xe4m\x8a\xbbAV\xf6\xdf\xb5B\xd6\xa3j\xde\x9d\x9b\x9b'
        b'\x9c\xc8\x0b\x8b#\xe59\x8b\x8a\x15s4\x88\x03<\xba\x93x|P\xa5wN\x05!?86\x8bs=(\xba_\xbf\xe2\xad\x08f`\xeaH\xcb\xe0\xc4\x02\xad\x01\x05\x93%\x08\x80~Q\xae\xdd\x13\t\xe4/n\x18\x0e'
        b'b6\x1e\xc7kB\xff\xd8\xd4\xabX\xc1\x9e\x15\xb2\xe3[\x86\xc4\xee\xf3\xf5>\x91\x97\xd4\xda\xb2\x00\x97\xf5\xfbd\x8d6%\xd9\xbbe4\x8f\xed\xa3\xac\xe8\xc4\x03 \xder\xd5\xf1\x86&|T\xc8\x15\n\x19\xa4:\xce\x95'
        b'\xc4\xaah\xd2\nc6-\x9c\x98\x18\xc7\xcd,K\xc6\x86*n\x93FIG~U\xf8\xdd\x05}\x8f\x7fNR\xe0\xac\t\x8ahYT\x0e9>\xf0c\xa2\x85\xc6"\x9a>\xc8\xf4\r\x8a\xe8\xe0[\xbf5\xb9\xaasG'
        b"'6\xaf\x12\xf6\xeeH\xa8\xac\x17ft\xa7\x12[w\xabV<\xads`\xcc\xaf\tQ\x83\xa4\xd9\xf4\x89\xea\x1ds\xfbW\xd5\xa91i\xd0\xc5\xb2\x88i\x11\xd0\xb4\x95)F1Z\xbd>;\xce\xe2GbFZSK"
        b'~C\xa1\xf8/\x8f&0[\x85\x9f\xe4z\x13i\x0f\xe1\xe7\xb9\x19HG\xe1\x0bN\xffBE\x9f\xe5\xf0Ak}\xb3\xc8\xaf yY5\xaca\xa2.\x84\x86,\xa1\xb2\xf2I\x1c(\xf0:8!\xfa\xeae\xac\xd4\xb7'
        b'\r[\xddI\r\x9bD\x94,\xa9\xc2\x8c\x91\x05\xe3\x8f\x03P\xdc\xdc\x86\x1d\xf3R1p\xba\xb7\xc2o\xbe\xc9\xcc\x19\xe2D\x10%\x88\xfa\xe3\xba\x98[\xbc\x1d\xd8\x12\x9f\xc2\x93\x97\xb5\x04\xb0\x8e\x11\x0c\xf8Z\x94\xa9\x97a'
        b'\x86<\x1f,\xf2\x97\x1fL\x0b\x9e`\xe0\xf5\xb2\x06F/\x90\x88V&1\x0e.28\xaf\xc2>\xb5\xbe\xec\x06\xc0\xb8\xbe\xe4Cl\xc7F\xcf\xd7\xb0S\x13\xb0\xde\xdb\x1f\xc5\xa6\xb1\x8e\xe7\xf4}\xd7[>\xd5\x1c#\x02'
        b'\xe2W\xb2O\xc8\xcfU\x9d\xa6\xfd\xb2\xff\x97\xd4\xfc\xdd\xbav\xf7\x14H\xe0\xfch\xa6\xfd\x112"\x8e\x0cU\x9b\x9f\x07\xa8\n\xcfa\xf1C-\xf2[\x03LW\xea\x1c\nQ\xa0\x1dc\x0b\xf7\xab\xdd\x10\x9c\xa6\xcc\xa0\xd2'
        b'\xfc#\xe9\xc5\xea\xa1\xd6\xce\xc0\xb8\x7f\x7f:2\xa4R\xcc\x17\xdf\x9b@ a\xc1s\xe0\x99_\x99W\xfc\xc4\x97\xeb\x1f\x1ax5\x8c,\x81i\x85CB\xbc)-)\xa1\xa4\xc9p\xd6;=\xe2\x86)G^\xb1pU'
        b'\xd6\xd3\xab\xd4\xca \xb4\x90\xbf\xb1u@\x01Bi\x10\x93o\xf9\xc5\x02P=\x89b|\xa6\xbe\xb7\x07\xfb\x07\xd60\x96(\xb5\xd0\xb3\xc5Rev(#\x00\xac\xe4\x99\xb2\x90\x11\x01;#\xe4@%\xa4\xc6!M\xc9\x1a'
        b"\x80\xe1\xe0y\xccvH\x96'k\x93\xb6\x81N\xe5\xfb\x83\xc1\xbd\xa7:Jde\x95E\x14*\x1b\xae\xddV\x0c\x12\xc8\x02\x85\x8eL\xae\xb2?ee7bA[\xc5B\x97,lL\xa8\x84Zt\xd0f%\xc0\x99,"
        b'j\xdf\xd2\xaf\x97<u|\xb2.\x99r#e\x1e&\xfa\x1e\xecX\x1f\x02\x90\x94N\xef\xda\x85\xc6\xca\xc4\x84\xc2.f\x19\xe5\xa17"\xa9\xf55X\x07\xb3\xb4\xce\x8c\x81y\x89\xa6\xf3[O\xc7?\xf8\xd3G\xde\xe0\xc2'
        b'\x9c\xf1Z\xa9\\[\x08\x7fL\x1d\xcb?\x99sS\xb7\xb1\x7fd\xde\xbfLc\x16\x8b\x06\x18_\x89\x8ac\x02\xb2`\x95\x10^8r\xcd\x06?M\x90\xde\x8c \x8e\xe6\x1fHDJ\xa7\xb5\xb2nN8\xb4\xf3\xf7=A'
        b'\x02\x97\x85\xd2\xd2c\xbe0\x95Vg0\x8c.\x1d\xb4 \xe1\x12\xe8\x1c\xc0\x98\x18u\x83\x80_\xf9\x9e\xec\xff$\x0fm\xday\x83f:8\xdb.\x0f\x00\xd0\x8fO|)\x1a\xd4;{/s\xe1\x10\xef\xcdmM\xba-'
        b'\xd0$\xb9\xc4u6\xf66\xb4\xd51a<=+\x8b\xd4\xf4\x98\x8d,\x01\xa81\x9b}\x0c\xfa\xe1\xdf\xc6\xc6\x08\xf5\x8d\x15)\x15K\xf8\x16wO\xebQ\x97\xd6\xdb{\r\xaa\xed\x04\x809#\xde,\\!"Z\xa0\xa5'
        b'\xad\xe1yg\xa6V\xdcG\xbe\x89gB\xe4\x10y\xb5o\xe5\xae\x11[j\x0c\xf2hm\xfe\xf8\xdbZ<\xb5\xaf\xfd\x18.\xe4\xfd\xab\x9f\xbd\xe8T\xfc\xb7\x97J\xfd\xa8\xdcs\x16\xb7\x90\x82\xb4\xab\xd3\xeb\x8c\xd8\xd1/\n'
        b'\xed\xc0\x82\x8a\xf3u\xcb\xea4\x9e9\x12_\xdd\xf2APkh\xccNk\xff?|\xf5\xfa,\x12\x1eu\xacq\xba=iN1D\xfdt\xf8\xc5\xf9\xe28\xcdI\xdb\x03\xed\xa2\xf6\xfe\x16\x94\xeb_\xb1x\x1b\x87/8'
        b'\xe67Gkj\xc8\x0f\xc93d\xdf\xdd>\x02{Aa\xdf\xfe\xd6H\xed0:\xb9\x86\xed<Y\xc8w\x0f\xf8\xe8\x80\n\xb9fz\x07u\xda\xe7?\x10\x148\xb7\xea\xfdD|\xbd?\xe5\x81AV\x18G\x9a\xd8\x8ej'
        b'z\x1deC\x87\xff\xa5\xbe\xdbv\xb8\xe9q\x7f\x1eyz\xae\xa4\x84\x941)\xee>\x83\x90\xe6R\x93\xf6\x0f\xb6o"\xd7p\x11bEt\xffU\xd9\x17S\xf3\x1a\x86S*\x9fs\xee\xc6\x94\xea}\xc2!\xa8\xbfd\x89'
        b'BF\xf7\xec\xb9\x92\x80]=\x8bD\xaaSH\xcf[\xfd?j+\x02\x8f\xfb\xc70\x0f\x84\xb4\r\xd0\xcc\xd5s\xb9\xfbr\x16Q\x8a\xe5\xbe\x1dP\xe6\xeb\xd2!\xecH\xe0Y\x9d\xe3\xdb\xce\xb5\x90!\x0b\xb4\xd9\xee\xe0\xbf'
        b'\tB\xbc\x90\xbc8!\xf4\t|\xc6\xbf\x99\xec\xca&\x0b"G\xc7\x8ez"\x92T\x17\x92\xc5\xfd\xfa\x19w\xe7\x15\xc87d\x12\xa7\xf9\xb5\xe1m$z\x15\x13\x14\xc1\xc0\x05\xf5\x19\xddO]\xc1|\x85\xb2\x82\xd0\x8e1'
        b'\x8f\x98t\x05\x14)2\x80\x07\x8f\x1b\xca\xc8\\\xc0\x06\xa0M\xa1N\xbc;t\t9\x8e!\xa2 \x01\x1f1\xfe\x17\x8al\x90J\x85\x9b\xd8\xe8Y-,\x06\xba\x12D\x81pI|pQW\xf4\xea\x02\x1cZ\xf4\xd2\xf2'
        b"ee0/8\xd7(\xe8\xe8\xe6\xf1QMV`:S\x13\x9d\x9cT\xce\xfc,\xcd\xee\xf8\x0f\xa5PM/\xce\xbc\x80\x82\x03'\x1e\x8b<e\x15\xcf\xa7\x92\xf5b\xc7\xd8\xa2m\xfdU\xe7|\xb7\xb8\xc1&\xb0\x10\xab\xbd"
        b"]\t\xc5\x19\x8e\x9bPFPsJ\xb3Uh\xb7\x15\xf6e\x1e\x93=mg\x05\xa5\xd5\x16\xd2o\x1d\x85'\x86\xdf\xa8\xdb\x7f\x8arRM\xf0\xa8\xb5-\xa8/\xfafL\x1f|\x02?\xa7@\x9b8\xb8\x17T1\xab\x96"
        b'\x9a\xa2\xd3h\xb0R\xe6\xa1vJ\x83\x06\x98\xa5\xa0\x86v\xb7\xae\xbf&\x96-\xf4;\xb2\x04\x91x\x8c\xe1\xb4\xbc/\x80FX\xe6\xb3\x01\xe7W\x16\xc2|\x05A\xf1\xb2\x9b\x82\x81\xff\xa3\x01\x03\x0e\xb2\xca$\xf5\xac\xaef'
        b'\x1d\x944<V/;\x03\x89\xac\xd9\xbc\xe0\xd0\xdc\xa5V\x81\xa5\xaf\x7f\xab\x12\xe2\xdaY\xb6\xfaT\xd9\xc5\xf8g\xa4\xd2kH\x19\x8c \xfc\xfe\x01\xc4\x80\xbd\xf3O\xaa$\x8d\xd7\x19\xce\xe0\xa75\xc4\xe3|M\xd2k\x80'
        b';\xb9\x9cp]\xa2\xd7\xdcf4cy-4\x7f>\xea\x02\xfa\xc4\xf9\xe9\xde=b?,\xdcNo\xd6#\xcb\xaa\xb4N\x16A\x0e\xc2\x7f\x93\xe2Y]\x06P\xdf\xf28(~\xea"\xd0.\x8cid\xdb}\xda\xb9\x84'
        b'\xeev\'\xd0\xcc\x13\xdb\xd6\x95\xec\x04\xab\xa1\xb6\xbf\xbdZ\x15gV\x8a\xa9\xb1\xf9F6\x82H\x1d"?/\x9f\xb1+A\x1e\xdcg\x82\x96A8)\x17\xeb\x02s"\xb8}\xc1\xc8\x82B\x97\x02&\x87\xaf\xc1s"@'
        b'm&\xf2 9\xbfH\xf2\xe0g\x9c\x89\x01V\t\xb8\\\x11\xc9q\xf2\xb1~x\x0e\xfc\xf7\xb5\x13\xd8\xa4Mz\xf25\xc8#\xaaOKn\x9c4*\x8a\xe3\xfe\x19^W\x1bI\xa3\x06\xaf\xc1\xb69ON{\x0c\xcda'
        b'\xa1\xfe\xa6&\xc7\xc7L\xdc\x0b\xf3\xe8\x00\x8b\x9c\xa5\x98\x0fgN}\xd1j\xbf?\xdd(\xfb\x9d\xf7\xa0:\xa5\x0e\x91\xc4b\xe3\x1a\xe7\xe6\xeb\x0e\xcfy\x0e+m\xf4\xed\x0e\x93g\x90\x84}g\x08\xcc\x18\x15\x1c\x94\x92V'
        b'"\xd3\x98\x92\xd5)\xf9-\x9d\xf3X\x08"\xe0\x03\xdd}l\xfb\xdbWJ\xa7\x17\xc3L\xe0\xde\xb6\x06\xc2\x1d\xe0zOa\xbd1~\xd6"\xf0L,\x1cW\xb7\x9a\xc07R\xf8\x14\xe9R\xa2\xda\xeaD\xbc\xd0\x06tm'
        b'\xad\x8f\x044\xfdT\xbf\xf0\x03\x95\x85l\xe0\xe1\xfdrt[\xf9c\x0e\xc2tW\x95"$\xd6\xa1\x00\xa5\x1aS\xc7\x0b\'\xd5\xe5\x15b\x1d\xd0\xf1"+\xf4\x03\x08\xcf^\x0f\x1eO1\x19\xcb\n\xa07 \xce\x12\xd6\xa5'
        b'\xebGv\xc8]\xa9\\\xec\xf9\xa4\xdc\x89\xbc\x8d\xf2f\xc9{\x10\xa3\xd2\xd3\xfe5\xa7\x987\xa9\x81eO\xef\x8bF\x13a\xed,\xd7\x832\xc3^\xc5o\xbf\xe1(\x83-]j\xe4\x85\r|6\x19\t\xa4\xa8\xf3A\x98'
        b'\xba/\x0e\xdb~\x94\xce<\x1c\x9e\x9c_KU9U\xd5\x08\x03\xe3B\xea\xfa\x03v\x89\x83n\x125\x04\x8c\x84\xc9\xf97\x183q\x9cW\x18\xb0(\x0b\xb0S\xde\x07\xef\xee\xfa\xe2b\xd9Y\x06\xd2?\xa5\xd2-\x184'
        b"\xd9\x0f\xee\xf4'n\xd9U\x8e)q\xdf\xe0\xc1\xe5\x80 K\xab9/\xf7(\xcb\x97\xedg\xc0\xe8\x0b\x98\xd0\xe2\xc4\xb6\x07E\xd6+\x86\xf2\xd4F\x0b\xd1{\x0e \xb8\x1f)Wc\x07\xc9\r\xf4(;Y\x99u0\xc8"
        b"C9\x8f\x1f\xe1Y\x9e\x10\xe0\xfd\xb8\x95\xb9\x07~\xf6l\xce6\x85\x93VY/D\x81\xb5#[\x07nh3\xe7\xb3`SE\x18\xce\xdc\xf5a[/e?0\xfd\xd6j'\x93T)\xf4\x8e\x1a\x12b\x82F\xc3\xaf"
        b'\xd8\xe8b\xf9\xff\x1c\xb7e[\xaf\xec< \xfe\xe9W\xc3\x7f\xf2(\x16.\xc5\x89\xce8\x80\x97\xc90=+O`B\x1c1\xef\x85W\xf5\x10\xb1}\xb7T\x08\xafSm\x93\rI\x15\xdd\xf22\xf3\xd5\x1f%\xcc\x13\xa0'
        b'\x08\x05\x1a\x8b\xad\x13<\x80\x03\xe7\xc7Kbt\xd4\xc7\xf1r\xd1\xa2\x8abm\xea1\xf5"\'\xf3C\x92 @L\x8aq\xa3\x0eR\xb9\xd0\xc3\xe9\x91\x9f\xc0\x18\xfe\x93\x8f\xff\xfeP \x0e;\x01d\\\xd3\x94,\xe8~'
        b'\x10Ub\x0bm\xce\xf5Kl\x95\xf6\xaa4\xe6\x89\xde\xfeOH\xeb\xde.\xc2\x9a\xfdj\xc3\xcf\x95V\x12\xa3\x04\xa3\x9f^}%\xaeT\xcc!\xc2j\xa3\x04HbG}\xde\xb2K\nw\xec\xcd\r\xac\xa2\xacZ\x9a\xe5'
        b'\rc\xd0\xebWpX\x14?\xfc\xd3\xc1\x90<\xe7\x86]\t\x1e\xa4\xb1\xb2CC\x06\xf0J\xf9\xe2\xddU\x04\x11N\xb8,r\x19C\x1c\xdcE\xf4\xf0\xe8m\xf5\x83\xdf\xff\x94\xefP\xa8\xc2\xb1\x82\x7f\xf4\x1b\xb1\x8d#`'
        b'\x92\x8c\xbf<\xd5\xff\x14\x0e\xccH\x8c\xd4$l\xa0}[t<\x87\xc8\x1b\xc4\xc3\x918W\xf8\xab\xe5\xddz0\xe9\x115\x80\x0b\x88\xf1\xbc \xd2\xef\x81vC\x7f+\xf1\x0cI\x8c\xea\xa1\xb2\xd9\\\xe8\x82\xdc\xd8\x15e'
        b'\xeb\x05"\xd4g\xf2\x1b\xb4\x86g\xec\x05\x07\x7fT\xfb\xe4\xe63\xd8\xf7[k\x93\xd3\xfb\x17\xbb_g\xa0o\x06\x80\x15\x95\tm1\xfbB\x90\x96,\x82\xc5u\xea\xf1cp\x137\xd7hw\xa6^\xb9{\xbbT\x18\x81'
        b'x\xdf\xa0\xe5\xb6\xd0\nT\x14X_\x900\x19\x11H\x9f\xa8\xb6\xfb\xf4\xc2\xcdL/s\x89\xa6\xee}\xa6.M\xd6\x1f\x0e\xb2\xff\x96\xf6\x80\xf8\x0eCa\xb8v\x0bHo\xf4\x8c\x15\xf3KY\x1c\xe1O\xc0\xf4\xc0\x92.'
        b'\xd5\xaf\x99\x97\xef\xc6\xe5\xea\r\t\xa8\x9c\xb4\xa6\xea\xe8\x01\xc7#g\x08o+\xda{\xa3\xbcd\xfc\xf8\xd5\xb9"\x87\xaa.\x8f\x85\xac\xb0\xee\xb3`O\xc5R"\xcf?\xb1J\x0c`h$x9\x8d\xf5\xd34\xfb\xab|'
        b'\xb5\xad\x13\xa4\xd3\x17\xcc\xa6\xb7\x94{8\t!,\xb5\x12\xdf\x8b"n\x1126a\x04\xee\x87\\\xbe\xdc\x04A\xd0\xd0Jk\xe7\x8e\xc3u\xce\x9b\xf2\x84ZLCa\xc9,bvxh,\xea\xe5\xf3W\xc4x\xd0\x93'
        b'\xfbI\x1fyl\x14\xad\xc1/\x8c\x87qh\x0f?X\x9eCn\xf4\x15\xe3\x92\x1e\x98\x9bC\xc2{\x8f\r\xb0\xfe]\xe1\x08{~Y\xafD\xef\r\xc3\xae\\\x90\xfenF`r\xbd\\I\xf3Io\xb2\xdf\xc4\x98i\x9a'
        b'\xffUq68\x8d@\xab>\x045o\xef\xa80$\x8d\xc4\t5H\xbb\xeft\xc0#\xa8\xa4\x85\x91\xea\xc1\x95\xc7\x9aE~\xee\xea\xbf\xe4\x9d\x18S\xac \xffw\xd2c\xd6I\x9a\xb1\xa8H\xf7C\xd13q\x9bN\xea'
        b"+B\x8a\xc1\xc8\x07\xc0\x8e[V\x08\xc6\x82Z\xe0\xe1\x1e\xcdm\xe8\x04\xaa\xb5\x03\xd0/OTT\xcb\xf3F\x12\xccu_d\xa5\x8f\x1fc\xa5\xcf/\xfd\xc0:\xf9G,_\xdcT\x19\xddh'\x93*\xf9\x13\x1a\xb3L"
        b'n\x8c+\xa8\xf6&`W\xdf\x08\xb2\xf4\x1a\xb3\xb50z\x06\xd8A\x18\xe6\xa8v\x9d\x00e\x8f\xa53\x15pu=;/t~v\x13\xfb\x0b\x9c\x06\x18^\xce\xad\x94C\x87S\xe5\xb5p$]9\x96q\x0e[h\xf5'
        b'\xd7\xe3\x07N\xc8o\xa0\xbd\xa4\xa6g\xf9\xe1\xa5\xde\xb6\xf7\x06\x94_\xeb\x91\xd7\xc7\xbe\xb6*\x93\xa4\xe6\t\xde_2]\xac\xec\xd4\xc7?\xaf\xe0\xa8w\xce\xb8\xb37\xfa\xec\x852\xe11\xa0\xe2\x1fD{\xe3\x13\xc6$\x83'
        b"\xf9<\xfb\xb9\xc1 M\x1c'\xbd\xef\xadfk\xf7g\xa4\x9a\xaa\x7f\x00\xb8n\x1e\xb7q\xc5\x0fQ{ynH\xb7R\xc6\xaa\x97?\xde\xf2\x9e\x90z\x0e\x87q\x12Lp\xe8\x83\xc2>\xcb\xf2\xe1B\xfcGk\x9a\x8aU"
        b'\x01\xa6\x92\x83\xe7\x92\xe7\xb1\x10\xf4\x01\x94qu\xc1\xbfX\x82o\xfe\x1c\xfb\xc0<\x9f\xf5\\\xcek\xbb\x89\xcd\xee\x8e\x13&\x98\\Ox\xb9v\t\xe8\xa8\xb6\x9e\xca\xb1VO\xe0\x0e{\xd9\xf8\xc4\xf80%\xe5\x9bB\xb5'
        b'\x18:\xcfl\xabRe\x12 d\xad\xfae\xd0\x93&\xa1C\xffh)Yy\xc2\x94\xa7\xdf^\xba\xe5\x18\xb3\xca":\xa4\t\xcf>\x97\xbc\x06=\x8c=D\xd1\xa7\x8e]\x19\xc8\xd8\x7f\xf5~\x96\xb6\x08<\xa6\'gP'
        b"D\xce\x96\x0c?\xd0zS\x9b\x10\x82OO7\xe9\xca\x8d\xe0\x1b\xa8.Sr59\x8e0+q\xc0\xc1<\xea\xcdd\x96\rL\xf3b-\xb8:0fh\x80\x9da\x10\xb1QS\xbc\x97\x10\x99'\xef\xfcG\x9c\xb6\x90"
        b'w\xf7`\x97\xfb\x12\xae+\xde`\x05\xea\xba\xe4\xea\x9fL\xee\xba^\\&\x19\xd9\xfb\x92U\xedX\x15\xdfU\x93\x83L\x8e\x03\x1f\x93\nB\x98\xf3\xaa\x9e:\xaf(\xed9\xab=I\x1d\xb2Le rp\xd9r<f'
        b'\tk#k\xb2Y\x1f[s\xaaZ\xda\x01!i\xe2\x979\xec\xd7!\xe5\x0c\xd0\x17\x8aoK0\x0e\xe6R\x81&\xf6;\x13\x94\xd2\xdb\x99\xe1y\r\x14a\xa3{c\xa3=;~\xdb\x85\xfb#\x88$u\xbb\x99\xbcH'
        b'\xd6\xe1\xd5R-\xd2+h\xd8\xb3\x14\x8a>H\x06\xa4P\x0bN\x0f\x0e\x15\x14&T\x80\x08\x9a(\x0f|k\xd3\x1d\xc4\xec;z\xc5\x83c\xba\xfe\xec\xc7\xcd\x8cN,\x9aao\x9c\x9d\xc1P\xf9\xd2\xbf\x9c\x15\xc0Y~'
        b'\xf7L] \x9c\x98\x8e.\xef\xeb\n\xdd\xd4\xa7\x7f\x14\xea8\x8d:\xe5\xce\xae!\xd0C\xaeH\xc6#o._b\x08\x99\x93\x07&i\xdaT\x87\xfe\x13\x8dGzz\xe0/H\xc5\xfce\xf8\xc3\xb9w\xe5\x96<\xa5\x9e'
        b'\xae\rJ\x9c\xcb\x9fS\x07\xdc\xef\xd4Sh\x92`5\xd9\xb3Q:\x884\xf5\x9f\xed\x99\xe2\xee\x8c\xe5@\x88\x12\x8b+?\xa3m\xb1W\x03\xc0e\xd4Kh\x92\x17Y}\x85b]\x9f\xe8UG\x86\xf9kY\xab\xe6\x04'
        b"W\xf5\x87\xb4\x9a\x17\x87e\xb6\x7f\xcd+\x9f1\xf0\x8d3\xdf]\xb28\x8a\x1c'\xb4\xb5k\x15\xf2~\xa11\xa9\xdfJ\xfe\xbc\x9c\x95$\xe0R\xbfm1\x06\xd9Lm\x1e\x0eO\xcb*\x8d\xe0\x8b\x19\xc0\xe1\x83]\xd1\xed"
        b'\x99+\n\xa3\x9a\xc3\x1fN\xfe\xbbC\xccA\xf8\xca\x85\xe7\x02\xc7y\x83O\xcf\xc7\x91\xac\x7f.\xaa\\\xc7\xea\x13\x1c\x9bB\x82\x80\xe8\xd7~\xa7\xd0\x06o:tZm\xc1D\xf0\xd8\xc5!\xc8\xb3A\x13M\x10\xcd\xac\x13'
        b'\xbf\x08\xab\xb3\xfe\x99\x9c\xf2GOYe\x086\x03B`\xdf\xd0\xb3\xae50\xff\x84\xd7|a\xc5n]\xc2\xd5\x98T\xa5\xff\xa8\x9c\x98*pE\xf3\xec$I\x997\xc1yXNn\x9c4\xf1\xd4W\x93*w\xee\xfd'
        b'?\x90P\xd3\xb9\xbd\xf5\xd0\\Lb\xbd|U\x00\xe8\xaf\xa1\xfb\xdeZ\x06;\x05v>t\xfa[\xbf\xff\x03\xf8\x08\xa00@\xa0\xd9\n^yP\xd2\x1d_h\xb9\xc4\x0ck\x19\x0e\xc2\xddZ\x15)\xb4\x86\x89\x7f\xa0v'
        b"e\n\x9c\xd7T\x7f\xdc\x14\xe4\xe6w\x1b\x86 \xd7>m\xe1A'q\xa5\x87\x0e\xee\xcf\x00\x1a\x03\xf7\x0e\x9b\xe1e_\x93\x8fM\xe6\r#\xd1\x01.\x9e8^5o#;\xfde\xca\x8a\xd3\xbe\xe3l\x01\x94\xa1\xa1\xec"
        b',\xe1\xf7\x84:\xdeG\x0e.\x87\xd52x\xf01\xe6\xff8\x1cn\xe5\xb0\xca\xe6\xcd)\xb7\xc6\xc1\xd6\xc2\x19\xe4\x8fcx"\xbeI\x97\xec`\xbbo}\xadE\x90\x01]\xca\x97\x8e:`\xcb\xd9\x7f\xca\x98A\x9e\xb28'
        b'\xeaH\\(!\xff\xae\xd4D\xb6p4\xa8\xfbr\xeb;\xa9Op\x95\xf7\x1f\x1f\xa8z8\x17\x10\x13\x96]\x06\xe4\xcc6\x03\xa9\xf0/\x90oS\x1f)\xa1"\xb4\xcat\xbeC\xcd.\xf7\x07\xfe\x84Ou(\xc5\x13\x04'
        b'\xac\x8d\x0c\xa8<OP\x1d\xc6\xf3\xe1\x91\xa1\x08- mPw\xd8\x8cF/?}\xdc{q\n\x1b\xd5\x9a`[\xfb\x83\xbc\xf9\x7f\xd9\xcai\xae>\x1f\xf4\xcb\x95\xee\xa8\xd1&\xf6u\x97]\xde\xba\xecL\x1f\xf6 \xfe'
        b'\xa8\xd0\x89\xa3\xe2\xf0\xba\xc6%Y\xeb\xf1\x05\x0c\xe9V\xc5,\xe8\x00}\xea\x05\xcfm\x93\xc5\x93\xad\xb0z\\\x1e\x0e\xf8\x04\xba\xc3\x1f\xd5\xc5\x80\x8aV\xc8uQ\xde\x97\xb9\xc1\x8a\xb6}\x14a\x94[\x01\xb15\xd1\xdeP'
        b'\xd4"\xfc\xd4\r\x984p\x10\xc7\x19i\x00\xe0s\xb8\xd1\x96\xd0\xb9\xecz2fbi$\xc0\xba\xf1J\xa1\x8a\xca\x9a\r\x0e\x04\x05\xff$\xd4Ws\x9fx\x11\xf2\x96\xc6\xc3\x9d"13\x17\xa7\xa1G\xdd?J\x89\xf0'
        b'k\x89\xed\xcf\x1e_y\xc0V\xb7\x14\xdd\xeaE\x92\x00\x8f#\xe6,$\xab\xb7\xcf\xd8\xb6\xe04\x81\xb4\xb0@\x907\xb7R\xa8a\xdf\x13Ps\xec4G\x15l\x8e\xb4\xac\x01\xb9<\x05\xb7\xdbi\xc6\xe3\x1f\xb9_\xd9\x1b'
        b"\x867\xd4 \x16\xb7\x90\xaf\xeb\xa5l\xa7C\x0b\xc0\x88'\xa2\xb6\xa3U\x049\xfd*\x9e\xbb\xd7\xd7\x9d\xe6Y8{Q\xec\xdf\x0f\x96\xa3Oh5zH\x04\xadi\xfc\xff\x05P\xc3\xce\x1e:\xe3\xe9\x8fw\xaa\xd0\xdb\x8e"
        b'j\x1d\xf0\x14\x95\x07\xb6\xb7[a\x100\x9b\xff\xb0{gM\xf3\x0e\xf8\x98\x96DR\xc5}\xf1\xb0Y\x938\xb8\xca\xb9@=\xaal\xc5\x1b\x01\x9b_\xdcJ\x97\xfb\x99\xf7\xed\xa4vXg\x9f\xa9J\xa9\xec\xec\x9c\x94\x9b'
        b'_@\x10\xe2\xd0\x06\xeb\x88\x04\xfbJ\xcf\x11\xc1\xdd4o\xa7\xa7\x0e+\x81\xeb2 \x05\x84;\xe9\x1d\x878\x11\xa88E\xde\xbd\xd9Q\x02Y\xf5\x13vg\x9e]\xc4:X\x9a\xbe\r\x0fV\xf7\x011\x1d\x08o\xf42'
        b')D:#%\x0b-\xd5\x826\xfbwE;Wt\x1c\x1eUy\xd7\xe26g \xac\x9a\xf8\xb3*\xab\xc7L\xff\xde\xd7\xe8\xaf\x18\x84\x81c\x96HY\x80/9\xcep\xa4\x96\xa8\x88\x8fgq5\x07\x84a\xf4\xf0\xac'
        b'"\xbf^\xe9\x1b<\xee\xd9\x97O\xe1\xbc\x06\xa9\x80\xf2\xd8\xd6\xd7\xab\r\xfb\x87(\xb5\xde\x0e9\xb1\x9c]\xdd\xc7\xd5\x89Z\x00\xc4\xe6\x86\xbd\x17q\xa8[`\xd2\xc5}\x15`\x02\x80\xa4\x1f\xdc;\x05\x86zD\xf8\x99\x86'
        b'U\xc9\xd6r\xf4\xe5\x8e\xf6\xfe\xeb\xf7M|\xae\x8c\x97)\x15\xfb@\x18\xaeL\xca\x11j"\x9e\xb1\xad\xed\xc4)s\xe8\xcev[\x81\x04j\xa5\x16JW2w\r\r2\x10n\xcb&\xfe\xd64\x05\xf9j\xa0\x99\xd4\x02'
        b'\xea\xf9\xd5\xe0\xe8mc\xa1\xff\xb0\xcd\xde\xa4\x07\xafi\xb95\xeds\x9a\xea\x8a\x90g\xb2(\xd7\x90\x88\xc2o{\x9d%\x98\x92U\xf5+\xde\xdd\xec[sb\x8e2\xda\xbe\xb4\xc5\xf1\xb0\xc4|QX\x8e\xbd\x9f\xeb56'
        b'=\xb2\xf3\xcaq\xaf\xe70&\x80G\x98%W/jx\xd953\n\xdc\x91\xc2\x1f\xba}\xa8\xd0"Vy\xe6zwsL\x16\x00X~\xcc\x1a\x1c\xd1r\xbf\xec\xcd\x9c:\x9c\x14\xd6\xd5z\x93eU\t\xe8?\xeaa'
        b'q<\xfe\x84\xf8\x8f\x1f\x19\x94\x06\xf1\xcc;\xac*\xcb\xecc\xf0$\xf4>\xd7A\xbfw\xd9W5\xab\x8bQOY\xfeh\x873\x11<\xfc\x87\xdd\x8a\xaf~i\xcd\t\xc3\xe2>\x08"i\x81\xc5\x10"u\x1d\xa0\x1eb'
        b'\xe3+\x1c\xc2\xd7SJ\x1b\xa8\xe60\xc4\xe4+\xdab\xe8=\x17\x8e\xcfm\xd1/\x90\xfb\xafL\x81\xa7\x0eN\x1bI\xb6~\x0c\xb1\xf05_\xfe\x14[`\x8f\xb1\x96\x1d\xb0\xffP?\x82\xb3\xfe\xcaI\x9b>^<\x98P'
        b'z(\xae\xa9\x11\xbf.\x10\xef.\x8cD\xa8J\xebp\xd38\x7f\x010\x1f\xd0\x87?X\xef\x96\x04\xb7\xf9I"\x0e\xef\xfeT\x8d\xa9\xd7\xd1\xf1\xb5\xfe%\x15U\xccI\x9d\xe3\x0f\xa2G\xe9\x96.\xc8\xed\xbe\x90.\xf7\xf4'
        b'*4A6\x7f\xacS\xc7d\xbb\\k:\x89\x8c.]\x0f\xf91\xb3\xfa\xc9\xc4\x82*\x8d\x92\xaf{\xaaL\xa41\xac#\xdf\x1d\xe2\xdag3Q\xfe3\xdb\xf0\xe5\xb1\xeb\r\x93\xc2\xfd\xbaR\xbd\x92+g\xa7rF\xef'
        b'\xe9\xe4\x00\n\xa3\xed\x9c\r\xe5\x15\x03\xb1T_9\xcfs\xeb\xd4\xee7\xf8W;\xd1ju\x17\x0ci\xb7\x88\x80\xa2n\xda\x85\xa0\x19\xa9\x1a\xa7\x0bWxUt\x8bh\x1e\xbe\x95\xfd\x94\xcd)E\x0f\xbb%4l\xc0\x8a'
        b'\xeb\xd8\xed\xf3\xf0\x1f\xd34]\x1bh\x13S}%\x98-\xfd\xb7\x19\xd9\x18\xd3\xf9\x04x\xd5\x89\xb1\xb2\x06M\x95<\xf4\xf4\xca\x9b\xa7\xc9O\xb5:\t\x17r \xa6\xa1\xe4\x08N\xeb<\x0f\tiW\x14\xde\x96@\x1b\xe9'
        b'\x1c\xf4\xfb\x89\xb7\xd8\x04<#\x06\xeb\xf0c\xdc%\r(\x858L\xf4\xb7,\xdc\x1b\xc7\xe0\xfaaEm\x92\xde5G\x8a"\xa0\x84\xc4\xec\xe5K\xf6g>\xfc\x11\xc9X\xd3~h\x8a\x18\xa7\xfd\xb3Y\xb17\xb5\xe4~'
        b'K\xdf\xe9U\xc9\xe1g[\x1d\x0b\t\xe6\xb8d\x11HC#}\x99\xac[\x00)W\xf0^\xc4\x93\xb5G\xb8\x92W\x071\xe1<\xae9\xc5\xc7\xd4\xc9(\xc1 E\xe2\x97\xbffl\xeb\xd8\xd9\ry\xc5\xea\xdb\xe0p$'
        b'\x18\xb4\xbc\x84\x9b\xc8y\'^\x072]\xd4\x06ib\x17\xf9\xe5\xa7Y\x0eZ\xe8\xb0\xe9l%"\xcc\xe4\xf5\xb8v[\x1c\x9c\xaf7\xb2\x1e+\x1a>\x0b\xf84\x18\xbc\x9d\xd1N\xe0\t4\xdc\xe4\xd8_\xc6\xf9\x98\xd9\xee'
        b'0\x84\t\xa4X\xa1b\xc0u\x97\x90\xe5\x0cYp5U\x8c\x17\x07eP\x1d)\xfa\xc8\xffy|\x172\x83\x87\x8a\x8f\xfe]J\xecn\xce\xe1\x14\x0fk0E&s$\xcd\xe8*\x08m\xd7\xcd\xfbv\xc3\xc4\xe3\x97\xb7'
        b'X\x93\x8d\x04\x1e4f{\r\xf9\xe5\x9a\x96\x9c\xc8\x03\x90\n2tx#P\xb5$\x8el}\xff"="*\xfb\x03\x94\xddJ\xa8\xd5z\x0c\xf8\\EewP5\xcbY\xaeR\xad\xe2N\x07U\xc8\x08yX\\H'
        b'\x9c\x96^\xbd\xa2]\x9fr\xa9\xccc\xae\xab+\xa0a\xfd_6\x0e\xea7\xd4b\x0b\x8b\xde\xc2\x13\x88\xaf~,\xa2\xea\xbakt\xdc\x9d\xa5QM\xf8\x00\x99e:I&\xf6t&\x0f[\xed\xb0B\xb1\xbbX\xc08\xf6'
        b'\x1b\x071\xa7q\x92\xfb<\xe0d\x11\xb2\xe1_0\xe3\xda\x9dg\xf7h\xeb\xdf\xad\xa3>F\x1d<\xc6\xf2\\L\x14:_\xb4\xd8^\x9at\xa4=\xb1\x03=-\xcb^_:\xcf\x83\x0f\x12[\xa0f\xe4O_*\x15\xfd'
        b'\xa0\xae\xa3\xb2a\xe1KHy\x86\x0e\xdf\xc0\xd5!\x04\x1b\xc3s^\xf1\xfdV\x01(\x17\xc9qLj\x95\xe0\xf8\xeb\xfe\xb3&ny?\xaaa\xf4M\x07\x0f\xa5dQ\x19"\x7f\xe1w\xdf\xb2.\x94O\xfeX\xacv\xe0'
        b'e\x10u\xfe\x1e\x95\xee\xfa\x92\xd4GR\x9e-\xc2\xb3\xe1\x86\xb8\xb42\xf93\xdd&<\xb7\xde\x7fW\xcd)"-\xc0\x97\xfbT\xcfFnr\xd4VDC\xe2\xd0l|BvB\x10\x07u\xe5\x16\xcc<\xba\x92\x1cp'
        b'\x91\xaa\x82\xf7-\xd4\n\x9d\xcbF\xcf\xf1\xccn\x0cc[\xb4R\xd7\xfcB\x9aa\\\xe0\x82Ok\xdf(\xf0A\xe0E+|\xda\x9b\xf4Y\xb3@9Qd\x08\xc5\x8c\x7f\x00+\x9c\x94\xac\x8f\xe7\x99\xe0_\xca\xeaP\xb7'
        b'to\x8f#.\xc55\xc2en\x10\t\x06\xb5;\xb6\xee(\xa5\x1b\x0er\x04\x19\xee\x00\x82\xb7\xf3\xfe\xef\xdb\x96?f\xab\x8e\x17Ki\xe3fl\x89\xed\xed`\x9aWP\r\xfd#\xc8\xcd\xba\xd3\xd1W\xb66M\xd0^'
        b'Rx\xd8<\xc6\x96\xd0$\x96u\xfb\x9d.\xdaE\x1a\xaf+`\x07\xdc\x88Ho\xb5\xfe\x0c?\xf8\xff\xed\xff\x14\xc2\xde\xcfS\xa1X\xc0\xed]\x810\x07\xf8{fut\x93\x99\xb1\x80S\x1d\xfc\xb8m\xeb\x91\xdf\x16\x9b'
        b"\xa1\xb7\xe2&'?\xec\xe9\x8f:sq\xb6\xb4\xdb\xcc\xaak\x1dr\xdb\xb1\xbf3\x19\xd5j\x06\x15\x8cy\xa6\x02\xa5\x17\xbf\xc7\x9a\xa7O\x92cf\x02\xa6bft\xb9\xc1K\xfc\xec\xc7(!F;\xcd\xe3\xd0\xe5\xec\xef"
        b'c1;QQ\xd2\x00\x87w\x8a\xa5\xb9k9N\x7f\x16S\x05\x04\x1b\x8e\xa0\xeaw\xff\x80\xf0\x02\x1aI\x03\xb5\x8e\xba\xdby!n\x19H\xc5\xa9\xce\xbb\xadQX\x0b$\xac\xb8+\x074)Ap\x89(\xf1,g\x94'
        b'\x94\xb8a\xc0*\x9a\xe4\x8f\x17\x90\xd4E\x87\xb1|\x89\x0e\x9e]\x80\x80r\xfb5{\x16`\xb7\x07B\xe7iX2#\xef\x04^\x9ai\xa9\x0e\x16k\xa7<\xd9\xe7p_\xb4\x85-\x96]4P\xc8\xf5I\x95\x91\xdd\x0e'
        b"\xa3&\x9f\xdf\x82\x87W$\n\x84cL\x90l\x87\x07\xd9\xf8\xf6k\xbf\xa6\x90n>Q\x03\xaa\x80\xacm\xd5\xf0\xd5b\xa7i}-#k\x02\xb1\xd73k\xfe:'Ef\x18K\xeffz\xb2_\\\x0b\xd0\xf0\xab&"
        b'=\xf0\xef\x15\xcb\xb9$\xc1S\x16\xe8\x9c\xcc"\x9aa\xdbd\xbd\xc7\xe1\xe5\x9f\\xo\xf6t\xe5:\xfar\x16\xa5h\xee\xf01a\xc8\xda\xa4\xd1\xeaJ\x0bY_\x07S{\x89\xcd\x96\x949G\xb4\xd9\xd1\x91\xbdJ\xd0'
        b'\xde\xe9S\xd9\xac\x80\xb2\xcc\xb91\x83\x1c_\x9c\xa2_\x15\xcb\xf7\xf4\x0bm;\x9ca\xa2\x8aoF9\xaa<Es\\\xb2n\x18\xfd3\xb0\xe9\xda\xad\xc8{\xbd\xb8\xd2\xd5G\r\xe0\xca\xa8\xc9\xf5\x05\xb3\x85\x07}\xd7\x84'
        b'\x03\xd8r_\x9f\xea+.\xff\xb9=&\xf0\x87 \xbc\xcb0\xa9\xf8w2~\x91\x94B\xa2\x196s&H\x99\xfc\x94]\xed)\xda\x0b&\xac\xa0\xb9\t\xf4R\x1aF\xdb\x1a\x0b\x19\x15\xcd\x02e\xc0\x94\xc8&\x13\xc0['
        b'\xbf\xd0Z\xd4\x8f\x9d\x1f\xea\xc0\x8c&!\xbd\xa2Z\x944\x92\xa8\xf2\xaf\xd2\x1a\x13e\xf6\xe4SR\x8c\x9d\\eX\x1a/>t\xd0\xd4\x10\x08\xd05\xe2;\r,\x08\x9f\xdf\xe6O\x1a\x01^\xb7*\x7f<\x03\xb4\x1a\xb8'
        b'~\xf6K\xb0\x19\x962\x90\xcfd`\x0e\xb7>\x90\x8f\x90\xe5\xba\xd4\x01&j@^\x9c\xb9N<e\x80j\x18\x08#w\xeb\x04`\x9f\x00.\x8a\xff\x0f`\x93\xa7\xf1\xf4\xbc\x02\xb9\xf6`5@\xb4\x020\xd7\xdb\xeby'
        b'%\xab\x81\xd281-\x08\xb1R\xceO$\xb3\x13\x7fOx/\xb9\xf3)\xcb\xb0;\xc2\x82\xb5\x9e4\x80\x9e:\xee\x8fk\xba\xbe.\xd8h\xff\xa3\xc62\x84\xeb\x01\xdf\x9dj\x17O\xea\xac\x1f6\xad\xa6\xf7\xca\x022{'
        b'\x1b\xd7>\xdb\xbb\xf0\x11\x92\xc3\x97\xec\x92-?\xcb\xbc\xa3\x82^7\xe5x\x86\xedE\xcd\xac\xa9\xd8O}m\xd4\x99rl\xbdW\xba\xdf\x17\xd4v\x10\xa8f\x87\x19t\xc3~]\xaa\xdd\xdcU+\xd6Y\x12N\x97\xbd\x14'
        b'\x1eQ\xad\x88\xfdJ!%\x92\xa8\xbe\xf8\xff\xa4K\x9c\x00\xe2\xa5\x19\xf4z\xef\xbf\xd0^\xc4%\xdbm\xa1\xa6\xb1\xfd\xf1<Y\xbbc\xd0\xe7i\x19\xb6\xd8\xd7\xd2[e\xe8)\x92ba\x03n\x03i\x8e\xcf\xfb\xa8\xf0\x01'
        b'\xfaR\xff\x18H\xf8\x8f\xbcia\x1c\xaf\xc2\x1d\x86o\xf7\xc6>E#+\xdf\x9fj\xb6\xf1?$*C\x9c\xe9\xd0\x97)q\xd0\x88-\x8amQn\xd4E\xae\xc6H\xeb?\x06\xba`\xc8\xaf\xe6\x8c\xe46a;u\xae'
        b'\x997,\xe8\x03\x8f7*\xe0\x91_3yw5\x03.\xb1\x995\xd2\xd1|-\xf6V\x85\x84\x9c\x98\xf0L2\xb5H\xfdZzG\x86iM\xd8E\x8eD\xc9\xc42K\xc0\xfcE\x9bQ\r\x01I\x19{\xcb\xf0\xb2k'
        b'g\xc0{\xf7\xd6f\x87\xfa@4\xa7\x1b\x88J\xf2U\x8e"\xcc_\x8c\x9fJ\x1b;?&~\x98G!\xa0u\xd0\xb8\x98\x1a\x05\x87\x08\x08\xee\x90^M\x7fLiM\x00\xfc\xde\xe1\x83\xd3\xe0s\xb2\xcd\x90\x06\xed[3'
        b'"\xf0\xdf\x92\xc2\x84\xe5[\xd2\x8d\x07\x89\xea%\x1d+\xd3 #4\xa5+\xf27g+]\xff\xc9IU\x9c\x8a\xc5\x13\x82,\xb5&\xe9\xec\'S\x92:*\x15\xe5\x87mX\x14\xb3\xf6/\x88\rm\xe9\x06\xbc\xb9\'o'
        b'>\xb8\x08\x08\xf1\xf9\xfd\x0b\x95\xf1=2\xfc\xb7\x9bj5\xc5\xd9\xac\x081\x13\x87u\xaf\x16\xf0\xa9\xc17i:\xc9C[mhK\xcc\x00\xb1\xeb\xf3\xd3\xa3J-\xe5iE\xd4\xab|\xb6\x0f2V-\xb0\x1f\x82[\xe2'
        b'{,_\x85S;}\x81\x1d\xda\xbd\x18\xb6`\xf5\xbf\x8d\x17\x7fZ\xdc\x99v4\xbc\x9c\x01\xcc\x9e\xf9\xb9J\x16c\t{\xb3\xbb\xcd\xeb0}\xae \xd1\x83\x8csNN\x8eVm\xb8X\xdc\xe7\xf9RW\xb9PM^'
        b'Fp\x1c\x8b}\x86\xa2\xad\xd3\x0c\xa9ZG\x0c\n\xe0\xcc\x1d\xb6\x18Q\x817\xc32\xa7\xeavv0]\x89V&l\xc8\x1a\xe1\x19\xe4\x93NFk\x92o\xd7\xa9g\xef\xff\x98I\xb8\xf8Y\x98\x0c\xd7\x19\xb1)\x07\xc0'
        b"\xb1\xb9\xc8\xe7r\xb7fC%I\xe4`\xcf\x9f\x1c\xecI\x83\xad\xfeC\x9c~L\x8fH\xa2\x17\x86X'&\x94\xdb\xb70\xcd\xf06\xf5\r\x80'D.\xa64\x838rX\xa6\x8a2Bv\xb2\x14\xfe\x82\xfa\x13\xdc\xc0"
        b'\x10\xdb\xd4u\xbe\xb2R\xe7\x9f.\x1a\r\xc84\x9a2tS\xae+\xa6C\x8e\x12x\x06\xd9t\xe4\xcd\x9b4\xc2\xb7\x88\x8fi\xd7\xf6\xe6\xe2\x18}`\xf4\x08\xe1;\xc1\xab\x07\x12\xbf\xa1\x0b\xbe\xa7\x82\xb0\xc0\xf2\xa1\x9bA'
        b'\xb7\x02\xaa\xb1\x13;\xa7\xf8\xc4\x0e\xdd\x1c\xac\x1f\x90}\x84F{C(M\x92\x04C\xb3k/Z\x9aT\xb7\x86\xd5\x91\xae\xb9e\xc5\xd4\xe6S?\xb04\xf2X\xc8\x12 qn\xb6\xb7\x01\x92\xf1\x83n\x9a\xa0h\xfa\x14'
        b'\xb6\xcc\x06\xdfGfX#\xd2@\xd5\x14\xb3^\x11\x041\x1d\xe1\xff3!\x90\xbd\xab\x8a\xe7s\xdb\xe7\xb7\x0c\xd55Gc\xb3t\x95H}\r\xabq\x83\x85{\xd0E\x12\x95v\x02\x14+\xd6\x11\xfaMz\x03c +'
        b'\xc3\xac\x8d\t\xd9\xbc\xe9J\\\xef\xa7x\x85\xb8\xf2\xa7\x8f\xf3T\r\xa3\xb2\xe6\xa3\x19\x97\xaf\x8f\xfa\x87KKY->\x06K\xac\xf2\xadA\xa7\xf4K\xf6\xc0\x15s\x7fl;dj\x1c\xfc\xc6\xbdh\x9c\xed\x837\xbc\x15'
        b"\xd4\x9e\xa0\x9e'\xd8p\x93?\xa5>t}>)G$=\xe3\x161\x7f\xdf\xd3H(4\xbda\x91\xc7\nVi\xb0\xe0\xc6.:\x16\xdf\xb1D\xeb\xb6\xf1M\x15%\xba\xac\x14\x10\xbf\xfe\xf6\n\xe9q\xf3\x84:c\x94"
        b')\xe4\xf7\xd6\'d"&\xf9\xdePe\xdc:6\xb1\xdeTl\x10.\x82\xa1A\xcez\xacQ\xaca\x19\xfecd$\xae\x0f\xd6\x84>\x19+7\xb5\x83\x02\xad\x13\xa7\x17\x9fX/\xb1p\x1f\x01J\xb2\xf2^w\xd0|'
        b'\x85]\x03\xee \xca\xacf\xde\x9b\x0e[\x11j\x91\xfc\xa1\x0c\xb6\x00\x05\xa2\xd9\xb9_\xae\xb3\r\xa1\xe0\xf2\xc5U\x93_\x05\xee\xa3\xc8\x82\x10<\xc8\xd4\xe5^C*\xc9E\xd0\x14\xb6\xe9m\x9b\xd6t\x86\xe9\xa5\xf3\xb3\x88'
        b'\xa6\x8a\xd0\x1f\x87\x80\xb5_a\xf1X\x17bQ\xf0\xab^\xfe\x063\x96U`\xea\xd4bV\x89\xce\xe3\x96"\'W[\xd3\xf0\xcbn\xd97\xe6\xdbI\xa0Z\xcd\x9bk.\x087\xdfE\xf1/RgQ5L\xcd\xdc\xb4'
        b"\xf0z\xc0\x0c\xa3T\x18\xc2\xc7\xa4L\xbc\xdb\xa8\xf3\xd4y\x93\x1a\xde!\xd9*\xdb\xb3\xeb\xc9\xcdtZ\x84n\x82'\xac\x89\xe52\x01\x0b\xceHA\xae\x9a\rE~;_/\xfb\xe9N\xabt\xff<\x89(\xb1\xe8\xfc\x0f"
        b"\x96/\x8d\xb4\xd50Z\x8a\xc5\x9e\xcf\x81\xefj\x9b\xb7\x9d\xe8P0\xed\xe8\xe8#\x0b\xbd\x08\x8a\xf76*\x12\x0c\x10\xf1f\x80\x0b\x9f*\xea'\x9c\x10\x01]\xf3u\xdf\x88[4g\x85Ea\xd8\xcfZ\x90\xa0\x9b\xf4#"
        b'\xban\xdb\xdf\xff\x90d\xaf\xf4\xf5\xb2\xd7\xb5\xbf\xcb\x02\x1e8\xc6\x1bIb\xf8\xf4\xe9\xd2\x99\x86o\xcbO\xfd\xd7\xd1\xab"\x14U5\xed\xbb\x03\x8f\x12\x9e\xad\xa0\x0f\xf8S\xe5_\\\xec\xad\x18yg\xd5g\x8e\x0f\xd36'
        b'I\x0f\x0e!\xe5p\xa2\x11\xf1\xab\xcc\x03\xc4\xa2\xd9\xd2\x05\x88\xa8\x93\xcc\xc1\xee\n!\xed\x08nr\x13\x84ya(\x13\xfa\xed\x1a_\x13So\xb4^8\xeb\x1f\xb3j\xabh\x7fr\xe1MVq\x92g\xa4\xf8l,\xf2'
        b'\xb7W\xc8J\xecuZ3.5I\x19E\xd70\xc4\xe6|\x86\x05j\\\xdd\x06\x0f\xa3R\xeb\x9aN\xeb\x8a$\xb2\x90\xdbF\x13\xea\xa8\x97\x86\xa4i\x1a\xa0\x92^\xe65\xaa\xb4\xf0l*\xbc\x07\x91\xedv(\x19\x95\x9b'
        b'\xde\xd2\xcb*U\xe6b\xfd\xda\x80b\xa8:""8i\xcc\xf5\x81\xdd\x17\xf6>\x1d\xd4\xca+\x9fc8\x1d\x92l\xa7\x89"\x8a\x9f 0hvc\x96a\x8d\x10nQ\x8a\xce\xd8\xa0A\xf7\x808 Y\x06\x1cl\x83'
        b'\x9f\xf4p\x12\xe5\xbe\x91y\x1e\x9e\x7f\x07\xf8p\xf00y\x14\xbcLkz\xd5\x80\x8b:8\x10\x0b\x9f\x16)IX,4L\xeb\xdf\xd4\xf2\xf7\xba&"-n\xb75\xc7El\xcf,\xec\xc5B[A\x02m\x12\xe1\x94'
        b'\x97\xe4\xa81_\xe2$\xf0\xb8\x89\x83\xae\xa5\x98\xb8p\xf4^\x10{s\xaf\x8bb\x97[x\xc9-\x9c\xadN\r\x8c\xbe\xcd\xbfK\xd2F\xa2\xbb\x9bo\xbc\xad\x10\xdb\xf7P9x>\x0cX\x12\x873-$)T2\xc7'
        b'2\xfd\xf3\x86\xe3\x07\xc6\xc8E\xd9\xc1\xba\xf7\xe5\x8c\xf0f\xc3\x9d\xf9\x9f\x90X\x00z\xef=\xd7\xec\x14.\x93\xd1>HD\xaf\x1c0\xb7\x97\xd3cw\x9d\xb9\xd0\xec\xffC@N\xed\xa7\x8b\xe0\xb2\xd2\x19\xacw\xd2\xef\xe9'
        b'\x9c\x95\xc4/6\x01\xb8H\xe6\x14c\x01qfs\xcafCbtu\xf2\xf0\xa0\xf0\x85I4\xea\xc9\xb7\xd8\x85\xfc\x90I\xd1\x8b\xaah\xfa\x12\xe6\x8b\xb2\x8c\x86\xe1\xa9\xf5u\xcb.%\xfd\x1b\xcc\xa9\xb9d\x11\xc4\xcf\xa0'
        b"\xca\x99kz/\xb0\xabjH:\x95\x14n\xf5\x17\xd2ZU\x9f}\xbc\xd3HPv'\xc1\xa7i\x00oz\xbe\xb1\xa1\x80\x84\xe04\x050+\t\xe5\xd8@\xe5n]\xf1\xa9\x80O\xbafl%\xb5\xc3=3\xcf\xf9\xfb"
        b'`\xf5\xb8\x12_V\xd1\xfb>\xf8\x04\xbb\x91\xda\x96V6\xb4o`\xb5\xde\x88\x07\x0eEg`3\x93+\xcf!\x7f\x1f\xf4\xceF\x9b\xfc\xb4\x03\x14\xae\x0c\n\xe8az[\x9e\xa6\x9b\xe0!p\xa1\xfd\x0f\xad\xf5\x9d\xfb\xf5'
        b'`\xdeF\xf6&k\x99B\xca\xdc\xb7\xa8\xd0\xed\n4QX\xb5R\xd0\xb2a\xe0H\xe6\xc3\xc2^d=\x103\xf1{\x0f\xbf|0\x00\x82\xbe\xdc\xde;D\xe2\xab\xec\xc8L\xf6\xbb\xee\xa4\x1fY\x1f\x9d\xe2\x97\xbdg@'
        b"\xa6p\xbc\xc2\xceI1\xe5\x0f\x12\xcc\xdcwR\x12'\x1f\xd6\x97\x9c\xddc\xdf\x80Z\xe9\xf4\x13\x8f`u\x8b\xba\xc9q\x0b}\xd8UR\xedie\x1cA0\xf2\xa1E\x17E/#\xadvJ\xc0n\xa1\xb1\xe3AMM"
        b'\x07\x15\xc9h\n\x18\xfe\xf1\xf5\x83q\xb1\xe2\xbb$Q\x89%\x1f\xb7\xd5\xf2\x00+\x1e^\xa1\xda\xfb\xf5_8\x1c\x1c\xdd\xf5QQv1x\xa8<\xa9\x12\xe7\xc8\xad\\\x92){\xf0P\x87\x9c\xcbv\x8c^\xed\xc2Ro'
        b'CF\xb2\xa9\x08\xbd\xf8\xfay*\xcb\xea\xd6\x12\x1c\xdb[\x013\x86Ij\x99=\xe0\xc5\x8a\x95\xa9rO\xddV\x9a&I\x1fH\x99\x13\x94\x9495\xe0=\xb9Z7E\xd8/\x02"t\xe5xf<6qB\x83='
        b'V \x90N)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__name__\xda\x08__file__\xa9\x00\xf3\x00\x00\x00\x00\xfa\x16<frozen fintech'
        b'.swift>\xfa\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00sJ\x00\x00\x00\xf0\x03\x01\x01\x01\xe0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd8\x00\x0b\x80\x0b\x88H\x90h\xf0'
        b'\x00\x00!DS\x10\xf1\x00\x00\x01ES\x10\xf4\x00\x00\x01ES\x10\xf0\x00\x00\x01ES\x10\xf0\x00\x00\x01ES\x10\xf0\x00\x00\x01ES\x10r\x08\x00\x00\x00'
    ))
